Class: Google::Apis::ServiceusageV1beta1::Aspect

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

Aspect represents Generic aspect. It is used to configure an aspect without making direct changes to service.proto

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Aspect

Returns a new instance of Aspect.



336
337
338
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 336

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

The type of this aspect configuration. Corresponds to the JSON property kind

Returns:

  • (String)


323
324
325
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 323

def kind
  @kind
end

#rulesArray<Google::Apis::ServiceusageV1beta1::AspectRule>

Optional. Rules of the Configuration. Corresponds to the JSON property rules



328
329
330
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 328

def rules
  @rules
end

#specHash<String,Object>

Content of the configuration. The underlying schema should be defined by Aspect owners as protobuf message under google/api/configaspects/proto. Corresponds to the JSON property spec

Returns:

  • (Hash<String,Object>)


334
335
336
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 334

def spec
  @spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



341
342
343
344
345
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 341

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @rules = args[:rules] if args.key?(:rules)
  @spec = args[:spec] if args.key?(:spec)
end