Class: Google::Apis::ServiceusageV1beta1::BackendRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

A backend rule provides configuration for an individual API element.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendRule

Returns a new instance of BackendRule.



680
681
682
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 680

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

The address of the API backend. The scheme is used to determine the backend protocol and security. The following schemes are accepted: SCHEME PROTOCOL SECURITY http:// HTTP None https:// HTTP TLS grpc:// gRPC None grpcs:// gRPC TLS It is recommended to explicitly include a scheme. Leaving out the scheme may cause constrasting behaviors across platforms. If the port is unspecified, the default is: - 80 for schemes without TLS - 443 for schemes with TLS For HTTP backends, use protocol to specify the protocol version. Corresponds to the JSON property address

Returns:

  • (String)


608
609
610
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 608

def address
  @address
end

#deadlineFloat

The number of seconds to wait for a response from a request. The default varies based on the request protocol and deployment environment. Corresponds to the JSON property deadline

Returns:

  • (Float)


614
615
616
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 614

def deadline
  @deadline
end

#disable_authBoolean Also known as: disable_auth?

When disable_auth is true, a JWT ID token won't be generated and the original " Authorization" HTTP header will be preserved. If the header is used to carry the original token and is expected by the backend, this field must be set to true to preserve the header. Corresponds to the JSON property disableAuth

Returns:

  • (Boolean)


622
623
624
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 622

def disable_auth
  @disable_auth
end

#jwt_audienceString

The JWT audience is used when generating a JWT ID token for the backend. This ID token will be added in the HTTP "authorization" header, and sent to the backend. Corresponds to the JSON property jwtAudience

Returns:

  • (String)


630
631
632
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 630

def jwt_audience
  @jwt_audience
end

#load_balancing_policyString

The load balancing policy used for connection to the application backend. Defined as an arbitrary string to accomondate custom load balancing policies supported by the underlying channel, but suggest most users use one of the standard policies, such as the default, "RoundRobin". Corresponds to the JSON property loadBalancingPolicy

Returns:

  • (String)


638
639
640
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 638

def load_balancing_policy
  @load_balancing_policy
end

#min_deadlineFloat

Deprecated, do not use. Corresponds to the JSON property minDeadline

Returns:

  • (Float)


643
644
645
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 643

def min_deadline
  @min_deadline
end

#operation_deadlineFloat

The number of seconds to wait for the completion of a long running operation. The default is no deadline. Corresponds to the JSON property operationDeadline

Returns:

  • (Float)


649
650
651
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 649

def operation_deadline
  @operation_deadline
end

#overrides_by_request_protocolHash<String,Google::Apis::ServiceusageV1beta1::BackendRule>

The map between request protocol and the backend address. Corresponds to the JSON property overridesByRequestProtocol



654
655
656
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 654

def overrides_by_request_protocol
  @overrides_by_request_protocol
end

#path_translationString

no-lint Corresponds to the JSON property pathTranslation

Returns:

  • (String)


659
660
661
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 659

def path_translation
  @path_translation
end

#protocolString

The protocol used for sending a request to the backend. The supported values are "http/1.1" and "h2". The default value is inferred from the scheme in the address field: SCHEME PROTOCOL http:// http/1.1 https:// http/1.1 grpc:// h2 grpcs:// h2 For secure HTTP backends (https://) that support HTTP/2, set this field to "h2" for improved performance. Configuring this field to non-default values is only supported for secure HTTP backends. This field will be ignored for all other backends. See https://www.iana.org/assignments/tls-extensiontype- values/tls-extensiontype-values.xhtml#alpn-protocol-ids for more details on the supported values. Corresponds to the JSON property protocol

Returns:

  • (String)


672
673
674
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 672

def protocol
  @protocol
end

#selectorString

Selects the methods to which this rule applies. Refer to selector for syntax details. Corresponds to the JSON property selector

Returns:

  • (String)


678
679
680
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 678

def selector
  @selector
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



685
686
687
688
689
690
691
692
693
694
695
696
697
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 685

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @deadline = args[:deadline] if args.key?(:deadline)
  @disable_auth = args[:disable_auth] if args.key?(:disable_auth)
  @jwt_audience = args[:jwt_audience] if args.key?(:jwt_audience)
  @load_balancing_policy = args[:load_balancing_policy] if args.key?(:load_balancing_policy)
  @min_deadline = args[:min_deadline] if args.key?(:min_deadline)
  @operation_deadline = args[:operation_deadline] if args.key?(:operation_deadline)
  @overrides_by_request_protocol = args[:overrides_by_request_protocol] if args.key?(:overrides_by_request_protocol)
  @path_translation = args[:path_translation] if args.key?(:path_translation)
  @protocol = args[:protocol] if args.key?(:protocol)
  @selector = args[:selector] if args.key?(:selector)
end