Class: Google::Apis::ServiceusageV1beta1::BatchEnableServicesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

Response message for the BatchEnableServices method. This response message is assigned to the response field of the returned Operation when that operation is done.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchEnableServicesResponse

Returns a new instance of BatchEnableServicesResponse.



782
783
784
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 782

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failuresArray<Google::Apis::ServiceusageV1beta1::EnableFailure>

If allow_partial_success is true, and one or more services could not be enabled, this field contains the details about each failure. Corresponds to the JSON property failures



775
776
777
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 775

def failures
  @failures
end

#servicesArray<Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV1Service>

The new state of the services after enabling. Corresponds to the JSON property services



780
781
782
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 780

def services
  @services
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



787
788
789
790
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 787

def update!(**args)
  @failures = args[:failures] if args.key?(:failures)
  @services = args[:services] if args.key?(:services)
end