Class: Google::Apis::ServiceusageV1beta1::ClientLibrarySettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

Details about how and where to publish client libraries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClientLibrarySettings

Returns a new instance of ClientLibrarySettings.



1052
1053
1054
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1052

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpp_settingsGoogle::Apis::ServiceusageV1beta1::CppSettings

Settings for C++ client libraries. Corresponds to the JSON property cppSettings



996
997
998
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 996

def cpp_settings
  @cpp_settings
end

#dotnet_settingsGoogle::Apis::ServiceusageV1beta1::DotnetSettings

Settings for Dotnet client libraries. Corresponds to the JSON property dotnetSettings



1001
1002
1003
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1001

def dotnet_settings
  @dotnet_settings
end

#go_settingsGoogle::Apis::ServiceusageV1beta1::GoSettings

Settings for Go client libraries. Corresponds to the JSON property goSettings



1006
1007
1008
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1006

def go_settings
  @go_settings
end

#java_settingsGoogle::Apis::ServiceusageV1beta1::JavaSettings

Settings for Java client libraries. Corresponds to the JSON property javaSettings



1011
1012
1013
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1011

def java_settings
  @java_settings
end

#launch_stageString

Launch stage of this version of the API. Corresponds to the JSON property launchStage

Returns:

  • (String)


1016
1017
1018
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1016

def launch_stage
  @launch_stage
end

#node_settingsGoogle::Apis::ServiceusageV1beta1::NodeSettings

Settings for Node client libraries. Corresponds to the JSON property nodeSettings



1021
1022
1023
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1021

def node_settings
  @node_settings
end

#php_settingsGoogle::Apis::ServiceusageV1beta1::PhpSettings

Settings for Php client libraries. Corresponds to the JSON property phpSettings



1026
1027
1028
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1026

def php_settings
  @php_settings
end

#python_settingsGoogle::Apis::ServiceusageV1beta1::PythonSettings

Settings for Python client libraries. Corresponds to the JSON property pythonSettings



1031
1032
1033
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1031

def python_settings
  @python_settings
end

#rest_numeric_enumsBoolean Also known as: rest_numeric_enums?

When using transport=rest, the client request will encode enums as numbers rather than strings. Corresponds to the JSON property restNumericEnums

Returns:

  • (Boolean)


1037
1038
1039
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1037

def rest_numeric_enums
  @rest_numeric_enums
end

#ruby_settingsGoogle::Apis::ServiceusageV1beta1::RubySettings

Settings for Ruby client libraries. Corresponds to the JSON property rubySettings



1043
1044
1045
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1043

def ruby_settings
  @ruby_settings
end

#versionString

Version of the API to apply these settings to. This is the full protobuf package for the API, ending in the version element. Examples: "google.cloud. speech.v1" and "google.spanner.admin.database.v1". Corresponds to the JSON property version

Returns:

  • (String)


1050
1051
1052
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1050

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1057

def update!(**args)
  @cpp_settings = args[:cpp_settings] if args.key?(:cpp_settings)
  @dotnet_settings = args[:dotnet_settings] if args.key?(:dotnet_settings)
  @go_settings = args[:go_settings] if args.key?(:go_settings)
  @java_settings = args[:java_settings] if args.key?(:java_settings)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @node_settings = args[:node_settings] if args.key?(:node_settings)
  @php_settings = args[:php_settings] if args.key?(:php_settings)
  @python_settings = args[:python_settings] if args.key?(:python_settings)
  @rest_numeric_enums = args[:rest_numeric_enums] if args.key?(:rest_numeric_enums)
  @ruby_settings = args[:ruby_settings] if args.key?(:ruby_settings)
  @version = args[:version] if args.key?(:version)
end