Class: Google::Apis::ServiceusageV1beta1::ConsumerQuotaLimit

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

Consumer quota settings for a quota limit.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConsumerQuotaLimit

Returns a new instance of ConsumerQuotaLimit.



1214
1215
1216
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1214

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allows_admin_overridesBoolean Also known as: allows_admin_overrides?

Whether admin overrides are allowed on this limit Corresponds to the JSON property allowsAdminOverrides

Returns:

  • (Boolean)


1164
1165
1166
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1164

def allows_admin_overrides
  @allows_admin_overrides
end

#is_preciseBoolean Also known as: is_precise?

Whether this limit is precise or imprecise. Corresponds to the JSON property isPrecise

Returns:

  • (Boolean)


1170
1171
1172
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1170

def is_precise
  @is_precise
end

#metricString

The name of the parent metric of this limit. An example name would be: compute.googleapis.com/cpus Corresponds to the JSON property metric

Returns:

  • (String)


1177
1178
1179
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1177

def metric
  @metric
end

#nameString

The resource name of the quota limit. An example name would be: projects/123/ services/compute.googleapis.com/consumerQuotaMetrics/compute.googleapis.com% 2Fcpus/limits/%2Fproject%2Fregion The resource name is intended to be opaque and should not be parsed for its component strings, since its representation could change in the future. Corresponds to the JSON property name

Returns:

  • (String)


1186
1187
1188
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1186

def name
  @name
end

#quota_bucketsArray<Google::Apis::ServiceusageV1beta1::QuotaBucket>

Summary of the enforced quota buckets, organized by quota dimension, ordered from least specific to most specific (for example, the global default bucket, with no quota dimensions, will always appear first). Corresponds to the JSON property quotaBuckets



1193
1194
1195
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1193

def quota_buckets
  @quota_buckets
end

#supported_locationsArray<String>

List of all supported locations. This field is present only if the limit has a region or zone dimension. Corresponds to the JSON property supportedLocations

Returns:

  • (Array<String>)


1199
1200
1201
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1199

def supported_locations
  @supported_locations
end

#traffic_sourceString

Indicates the traffic type attribution for this quota limit (e.g. agentic). This is an informational field used to categorize and filter the quota limits. Corresponds to the JSON property trafficSource

Returns:

  • (String)


1205
1206
1207
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1205

def traffic_source
  @traffic_source
end

#unitString

The limit unit. An example unit would be 1/project/regionNote that projectandregionare not placeholders in this example; the literal charactersand`occur in the string. Corresponds to the JSON propertyunit`

Returns:

  • (String)


1212
1213
1214
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1212

def unit
  @unit
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1219

def update!(**args)
  @allows_admin_overrides = args[:allows_admin_overrides] if args.key?(:allows_admin_overrides)
  @is_precise = args[:is_precise] if args.key?(:is_precise)
  @metric = args[:metric] if args.key?(:metric)
  @name = args[:name] if args.key?(:name)
  @quota_buckets = args[:quota_buckets] if args.key?(:quota_buckets)
  @supported_locations = args[:supported_locations] if args.key?(:supported_locations)
  @traffic_source = args[:traffic_source] if args.key?(:traffic_source)
  @unit = args[:unit] if args.key?(:unit)
end