Class: Google::Apis::ServiceusageV1beta1::ContentSecurityProvider

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

ContentSecurityProvider contains the name of content security provider.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContentSecurityProvider

Returns a new instance of ContentSecurityProvider.



1342
1343
1344
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1342

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name of security service for content scanning, such as Google Cloud Model Armor or supported third-party ISV solutions. If it is Google 1P service, the name should be prefixed with services/. If it is a 3P service, the format needs to be documented. The currently supported values are: - services/ modelarmor.googleapis.com for Google Cloud Model Armor. Corresponds to the JSON property name

Returns:

  • (String)


1340
1341
1342
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1340

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1347
1348
1349
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1347

def update!(**args)
  @name = args[:name] if args.key?(:name)
end