Class: Google::Apis::ServiceusageV1beta1::Context

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

Context defines which contexts an API requests. Example: context: rules: - selector: "*" requested: - google.rpc.context.ProjectContext - google.rpc. context.OriginContext The above specifies that all methods in the API request google.rpc.context.ProjectContext and google.rpc.context.OriginContext. Available context types are defined in package google.rpc.context. This also provides mechanism to allowlist any protobuf message extension that can be sent in grpc metadata using “x-goog-ext--bin” and “x-goog-ext--jspb” format. For example, list any service specific protobuf types that can appear in grpc metadata as follows in your yaml file: Example: context: rules: - selector: " google.example.library.v1.LibraryService.CreateBook" allowed_request_extensions: - google.foo.v1.NewExtension allowed_response_extensions: - google.foo.v1.NewExtension You can also specify extension ID instead of fully qualified extension name here.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Context

Returns a new instance of Context.



1375
1376
1377
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rulesArray<Google::Apis::ServiceusageV1beta1::ContextRule>

A list of RPC context rules that apply to individual API methods. NOTE: All service configuration rules follow "last one wins" order. Corresponds to the JSON property rules



1373
1374
1375
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1373

def rules
  @rules
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1380
1381
1382
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1380

def update!(**args)
  @rules = args[:rules] if args.key?(:rules)
end