Class: Google::Apis::ServiceusageV1beta1::DisableServiceResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

Response message for the DisableService method. This response message is assigned to the response field of the returned Operation when that operation is done.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DisableServiceResponse

Returns a new instance of DisableServiceResponse.



1617
1618
1619
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1617

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#serviceGoogle::Apis::ServiceusageV1beta1::GoogleApiServiceusageV1Service

A service that is available for use by the consumer. Corresponds to the JSON property service



1615
1616
1617
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1615

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1622
1623
1624
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1622

def update!(**args)
  @service = args[:service] if args.key?(:service)
end