Class: Google::Apis::ServiceusageV1beta1::EnableFailure
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::EnableFailure
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
Provides error messages for the failing services.
Instance Attribute Summary collapse
-
#error_message ⇒ String
An error message describing why the service could not be enabled.
-
#service_id ⇒ String
The service id of a service that could not be enabled.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EnableFailure
constructor
A new instance of EnableFailure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EnableFailure
Returns a new instance of EnableFailure.
1860 1861 1862 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1860 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_message ⇒ String
An error message describing why the service could not be enabled.
Corresponds to the JSON property errorMessage
1853 1854 1855 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1853 def @error_message end |
#service_id ⇒ String
The service id of a service that could not be enabled.
Corresponds to the JSON property serviceId
1858 1859 1860 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1858 def service_id @service_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1865 1866 1867 1868 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1865 def update!(**args) @error_message = args[:error_message] if args.key?(:error_message) @service_id = args[:service_id] if args.key?(:service_id) end |