Class: Google::Apis::ServiceusageV1beta1::EnableRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

The consumer policy rule that defines enabled services and groups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EnableRule

Returns a new instance of EnableRule.



1894
1895
1896
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1894

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_typeString

Client and resource project enable type. Corresponds to the JSON property enableType

Returns:

  • (String)


1879
1880
1881
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1879

def enable_type
  @enable_type
end

#servicesArray<String>

The names of the services that are enabled. Example: services/storage. googleapis.com. Corresponds to the JSON property services

Returns:

  • (Array<String>)


1885
1886
1887
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1885

def services
  @services
end

#valuesArray<String>

The names of the services or service groups that are enabled. Example: services/storage.googleapis.com, groups/googleServices, groups/allServices . Corresponds to the JSON property values

Returns:

  • (Array<String>)


1892
1893
1894
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1892

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1899
1900
1901
1902
1903
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1899

def update!(**args)
  @enable_type = args[:enable_type] if args.key?(:enable_type)
  @services = args[:services] if args.key?(:services)
  @values = args[:values] if args.key?(:values)
end