Class: Google::Apis::ServiceusageV1beta1::Endpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

Endpoint describes a network address of a service that serves a set of APIs. It is commonly known as a service endpoint. A service may expose any number of service endpoints, and all service endpoints share the same service definition, such as quota limits and monitoring metrics. Example: type: google.api. Service name: library-example.googleapis.com endpoints: # Declares network address https://library-example.googleapis.com # for service library- example.googleapis.com. The https scheme # is implicit for all service endpoints. Other schemes may be # supported in the future. - name: library- example.googleapis.com allow_cors: false - name: content-staging-library- example.googleapis.com # Allows HTTP OPTIONS calls to be passed to the API frontend, for it # to decide whether the subsequent cross-origin request is allowed # to proceed. allow_cors: true

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Endpoint

Returns a new instance of Endpoint.



1985
1986
1987
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1985

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aliasesArray<String>

Aliases for this endpoint, these will be served by the same UrlMap as the parent endpoint, and will be provisioned in the GCP stack for the Regional Endpoints. Corresponds to the JSON property aliases

Returns:

  • (Array<String>)


1960
1961
1962
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1960

def aliases
  @aliases
end

#allow_corsBoolean Also known as: allow_cors?

Allowing CORS, aka cross-domain traffic, would allow the backends served from this endpoint to receive and respond to HTTP OPTIONS requests. The response will be used by the browser to determine whether the subsequent cross-origin request is allowed to proceed. Corresponds to the JSON property allowCors

Returns:

  • (Boolean)


1969
1970
1971
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1969

def allow_cors
  @allow_cors
end

#nameString

The canonical name of this endpoint. Corresponds to the JSON property name

Returns:

  • (String)


1975
1976
1977
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1975

def name
  @name
end

#targetString

The specification of an Internet routable address of API frontend that will handle requests to this API Endpoint. It should be either a valid IPv4 address or a fully-qualified domain name. For example, "8.8.8.8" or "myservice.appspot.com". Corresponds to the JSON property target

Returns:

  • (String)


1983
1984
1985
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1983

def target
  @target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1990
1991
1992
1993
1994
1995
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1990

def update!(**args)
  @aliases = args[:aliases] if args.key?(:aliases)
  @allow_cors = args[:allow_cors] if args.key?(:allow_cors)
  @name = args[:name] if args.key?(:name)
  @target = args[:target] if args.key?(:target)
end