Class: Google::Apis::ServiceusageV1beta1::Enum

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

Enum type definition. New usages of this message as an alternative to EnumDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Enum

Returns a new instance of Enum.



2037
2038
2039
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2037

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editionString

The source edition string, only valid when syntax is SYNTAX_EDITIONS. Corresponds to the JSON property edition

Returns:

  • (String)


2009
2010
2011
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2009

def edition
  @edition
end

#enumvalueArray<Google::Apis::ServiceusageV1beta1::EnumValue>

Enum value definitions. Corresponds to the JSON property enumvalue



2014
2015
2016
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2014

def enumvalue
  @enumvalue
end

#nameString

Enum type name. Corresponds to the JSON property name

Returns:

  • (String)


2019
2020
2021
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2019

def name
  @name
end

#optionsArray<Google::Apis::ServiceusageV1beta1::Option>

Protocol buffer options. Corresponds to the JSON property options



2024
2025
2026
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2024

def options
  @options
end

#source_contextGoogle::Apis::ServiceusageV1beta1::SourceContext

SourceContext represents information about the source of a protobuf element, like the file in which it is defined. Corresponds to the JSON property sourceContext



2030
2031
2032
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2030

def source_context
  @source_context
end

#syntaxString

The source syntax. Corresponds to the JSON property syntax

Returns:

  • (String)


2035
2036
2037
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2035

def syntax
  @syntax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2042
2043
2044
2045
2046
2047
2048
2049
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2042

def update!(**args)
  @edition = args[:edition] if args.key?(:edition)
  @enumvalue = args[:enumvalue] if args.key?(:enumvalue)
  @name = args[:name] if args.key?(:name)
  @options = args[:options] if args.key?(:options)
  @source_context = args[:source_context] if args.key?(:source_context)
  @syntax = args[:syntax] if args.key?(:syntax)
end