Class: Google::Apis::ServiceusageV1beta1::Field

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

A single field of a message type. New usages of this message as an alternative to FieldDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Field

Returns a new instance of Field.



2191
2192
2193
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2191

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cardinalityString

The field cardinality. Corresponds to the JSON property cardinality

Returns:

  • (String)


2141
2142
2143
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2141

def cardinality
  @cardinality
end

#default_valueString

The string value of the default value of this field. Proto2 syntax only. Corresponds to the JSON property defaultValue

Returns:

  • (String)


2146
2147
2148
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2146

def default_value
  @default_value
end

#json_nameString

The field JSON name. Corresponds to the JSON property jsonName

Returns:

  • (String)


2151
2152
2153
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2151

def json_name
  @json_name
end

#kindString

The field type. Corresponds to the JSON property kind

Returns:

  • (String)


2156
2157
2158
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2156

def kind
  @kind
end

#nameString

The field name. Corresponds to the JSON property name

Returns:

  • (String)


2161
2162
2163
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2161

def name
  @name
end

#numberFixnum

The field number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


2166
2167
2168
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2166

def number
  @number
end

#oneof_indexFixnum

The index of the field type in Type.oneofs, for message or enumeration types. The first type has index 1; zero means the type is not in the list. Corresponds to the JSON property oneofIndex

Returns:

  • (Fixnum)


2172
2173
2174
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2172

def oneof_index
  @oneof_index
end

#optionsArray<Google::Apis::ServiceusageV1beta1::Option>

The protocol buffer options. Corresponds to the JSON property options



2177
2178
2179
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2177

def options
  @options
end

#packedBoolean Also known as: packed?

Whether to use alternative packed wire representation. Corresponds to the JSON property packed

Returns:

  • (Boolean)


2182
2183
2184
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2182

def packed
  @packed
end

#type_urlString

The field type URL, without the scheme, for message or enumeration types. Example: "type.googleapis.com/google.protobuf.Timestamp". Corresponds to the JSON property typeUrl

Returns:

  • (String)


2189
2190
2191
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2189

def type_url
  @type_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2196

def update!(**args)
  @cardinality = args[:cardinality] if args.key?(:cardinality)
  @default_value = args[:default_value] if args.key?(:default_value)
  @json_name = args[:json_name] if args.key?(:json_name)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @number = args[:number] if args.key?(:number)
  @oneof_index = args[:oneof_index] if args.key?(:oneof_index)
  @options = args[:options] if args.key?(:options)
  @packed = args[:packed] if args.key?(:packed)
  @type_url = args[:type_url] if args.key?(:type_url)
end