Class: Google::Apis::ServiceusageV1beta1::FieldPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::FieldPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
Google API Policy Annotation This message defines a simple API policy annotation that can be used to annotate API request and response message fields with applicable policies. One field may have multiple applicable policies that must all be satisfied before a request can be processed. This policy annotation is used to generate the overall policy that will be used for automatic runtime policy enforcement and documentation generation.
Instance Attribute Summary collapse
-
#resource_permission ⇒ String
Specifies the required permission(s) for the resource referred to by the field.
-
#resource_type ⇒ String
Specifies the resource type for the resource referred to by the field.
-
#selector ⇒ String
Selects one or more request or response message fields to apply this
FieldPolicy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FieldPolicy
constructor
A new instance of FieldPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FieldPolicy
Returns a new instance of FieldPolicy.
2252 2253 2254 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2252 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_permission ⇒ String
Specifies the required permission(s) for the resource referred to by the field.
It requires the field contains a valid resource reference, and the request
must pass the permission checks to proceed. For example, "resourcemanager.
projects.get".
Corresponds to the JSON property resourcePermission
2235 2236 2237 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2235 def @resource_permission end |
#resource_type ⇒ String
Specifies the resource type for the resource referred to by the field.
Corresponds to the JSON property resourceType
2240 2241 2242 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2240 def resource_type @resource_type end |
#selector ⇒ String
Selects one or more request or response message fields to apply this
FieldPolicy. When a FieldPolicy is used in proto annotation, the selector
must be left as empty. The service config generator will automatically fill
the correct value. When a FieldPolicy is used in service config, the
selector must be a comma-separated string with valid request or response field
paths, such as "foo.bar" or "foo.bar,foo.baz".
Corresponds to the JSON property selector
2250 2251 2252 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2250 def selector @selector end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2257 2258 2259 2260 2261 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2257 def update!(**args) @resource_permission = args[:resource_permission] if args.key?(:resource_permission) @resource_type = args[:resource_type] if args.key?(:resource_type) @selector = args[:selector] if args.key?(:selector) end |