Class: Google::Apis::ServiceusageV1beta1::GoogleApiService
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::GoogleApiService
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
Service is the root object of Google API service configuration (service
config). It describes the basic information about a logical service, such as
the service name and the user-facing title, and delegates other aspects to sub-
sections. Each sub-section is either a proto message or a repeated proto
message that configures a specific aspect, such as auth. For more information,
see each proto message definition. Example: type: google.api.Service name:
calendar.googleapis.com title: Google Calendar API apis: - name: google.
calendar.v3.Calendar visibility: rules: - selector: "google.calendar.v3."
restriction: PREVIEW backend: rules: - selector: "google.calendar.v3."
address: calendar.example.com authentication: providers: - id:
google_calendar_auth jwks_uri: https://www.googleapis.com/oauth2/v1/certs
issuer: https://securetoken.google.com rules: - selector: "*" requirements:
provider_id: google_calendar_auth
Instance Attribute Summary collapse
-
#apis ⇒ Array<Google::Apis::ServiceusageV1beta1::Api>
A list of API interfaces exported by this service.
-
#aspects ⇒ Array<Google::Apis::ServiceusageV1beta1::Aspect>
Configuration aspects.
-
#authentication ⇒ Google::Apis::ServiceusageV1beta1::Authentication
Authenticationdefines the authentication configuration for API methods provided by an API service. -
#backend ⇒ Google::Apis::ServiceusageV1beta1::Backend
Backenddefines the backend configuration for a service. -
#billing ⇒ Google::Apis::ServiceusageV1beta1::Billing
Billing related configuration of the service.
-
#config_version ⇒ Fixnum
Obsolete.
-
#context ⇒ Google::Apis::ServiceusageV1beta1::Context
Contextdefines which contexts an API requests. -
#control ⇒ Google::Apis::ServiceusageV1beta1::Control
Selects and configures the service controller used by the service.
-
#custom_error ⇒ Google::Apis::ServiceusageV1beta1::CustomError
Customize service error responses.
-
#documentation ⇒ Google::Apis::ServiceusageV1beta1::Documentation
Documentationprovides the information for describing a service. -
#endpoints ⇒ Array<Google::Apis::ServiceusageV1beta1::Endpoint>
Configuration for network endpoints.
-
#enums ⇒ Array<Google::Apis::ServiceusageV1beta1::Enum>
A list of all enum types included in this API service.
-
#http ⇒ Google::Apis::ServiceusageV1beta1::Http
Defines the HTTP configuration for an API service.
-
#id ⇒ String
A unique ID for a specific instance of this message, typically assigned by the client for tracking purpose.
-
#logging ⇒ Google::Apis::ServiceusageV1beta1::Logging
Logging configuration of the service.
-
#logs ⇒ Array<Google::Apis::ServiceusageV1beta1::LogDescriptor>
Defines the logs used by this service.
-
#metrics ⇒ Array<Google::Apis::ServiceusageV1beta1::MetricDescriptor>
Defines the metrics used by this service.
-
#monitored_resources ⇒ Array<Google::Apis::ServiceusageV1beta1::MonitoredResourceDescriptor>
Defines the monitored resources used by this service.
-
#monitoring ⇒ Google::Apis::ServiceusageV1beta1::Monitoring
Monitoring configuration of the service.
-
#name ⇒ String
The service name, which is a DNS-like logical identifier for the service, such as
calendar.googleapis.com. -
#producer_project_id ⇒ String
The Google project that owns this service.
-
#publishing ⇒ Google::Apis::ServiceusageV1beta1::Publishing
This message configures the settings for publishing Google Cloud Client libraries generated from the service config.
-
#quota ⇒ Google::Apis::ServiceusageV1beta1::Quota
Quota configuration helps to achieve fairness and budgeting in service usage.
-
#source_info ⇒ Google::Apis::ServiceusageV1beta1::SourceInfo
Source information used to create a Service Config Corresponds to the JSON property
sourceInfo. -
#system_parameters ⇒ Google::Apis::ServiceusageV1beta1::SystemParameters
System parameter configuration A system parameter is a special kind of parameter defined by the API system, not by an individual API.
-
#system_types ⇒ Array<Google::Apis::ServiceusageV1beta1::Type>
A list of all proto message types included in this API service.
-
#title ⇒ String
The product title for this service, it is the name displayed in Google Cloud Console.
-
#types ⇒ Array<Google::Apis::ServiceusageV1beta1::Type>
A list of all proto message types included in this API service.
-
#usage ⇒ Google::Apis::ServiceusageV1beta1::Usage
Configuration controlling usage of a service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleApiService
constructor
A new instance of GoogleApiService.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleApiService
Returns a new instance of GoogleApiService.
2639 2640 2641 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2639 def initialize(**args) update!(**args) end |
Instance Attribute Details
#apis ⇒ Array<Google::Apis::ServiceusageV1beta1::Api>
A list of API interfaces exported by this service. Only the name field of
the google.protobuf.Api needs to be provided by the configuration author, as
the remaining fields will be derived from the IDL during the normalization
process. It is an error to specify an API interface here which cannot be
resolved against the associated IDL files.
Corresponds to the JSON property apis
2351 2352 2353 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2351 def apis @apis end |
#aspects ⇒ Array<Google::Apis::ServiceusageV1beta1::Aspect>
Configuration aspects. This is a repeated field to allow multiple aspects to
be configured. The kind field in each ConfigAspect specifies the type of
aspect. The spec field contains the configuration for that aspect. The schema
for the spec field is defined by the backend service owners.
Corresponds to the JSON property aspects
2359 2360 2361 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2359 def aspects @aspects end |
#authentication ⇒ Google::Apis::ServiceusageV1beta1::Authentication
Authentication defines the authentication configuration for API methods
provided by an API service. Example: name: calendar.googleapis.com
authentication: providers: - id: google_calendar_auth jwks_uri: https://www.
googleapis.com/oauth2/v1/certs issuer: https://securetoken.google.com rules: -
selector: "*" requirements: provider_id: google_calendar_auth - selector:
google.calendar.Delegate oauth: canonical_scopes: https://www.googleapis.com/
auth/calendar.read
Corresponds to the JSON property authentication
2370 2371 2372 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2370 def authentication @authentication end |
#backend ⇒ Google::Apis::ServiceusageV1beta1::Backend
Backend defines the backend configuration for a service.
Corresponds to the JSON property backend
2375 2376 2377 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2375 def backend @backend end |
#billing ⇒ Google::Apis::ServiceusageV1beta1::Billing
Billing related configuration of the service. The following example shows how
to configure monitored resources and metrics for billing,
consumer_destinations is the only supported destination and the monitored
resources need at least one label key cloud.googleapis.com/location to
indicate the location of the billing usage, using different monitored
resources between monitoring and billing is recommended so they can be evolved
independently: monitored_resources: - type: library.googleapis.com/
billing_branch labels: - key: cloud.googleapis.com/location description: |
Predefined label to support billing location restriction. - key: city
description: | Custom label to define the city where the library branch is
located in. - key: name description: Custom label to define the name of the
library branch. metrics: - name: library.googleapis.com/book/borrowed_count
metric_kind: DELTA value_type: INT64 unit: "1" billing: consumer_destinations:
- monitored_resource: library.googleapis.com/billing_branch metrics: - library.
googleapis.com/book/borrowed_count
Corresponds to the JSON property
billing
2394 2395 2396 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2394 def billing @billing end |
#config_version ⇒ Fixnum
Obsolete. Do not use. This field has no semantic meaning. The service config
compiler always sets this field to 3.
Corresponds to the JSON property configVersion
2400 2401 2402 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2400 def config_version @config_version end |
#context ⇒ Google::Apis::ServiceusageV1beta1::Context
Context defines which contexts an API requests. Example: context: rules: -
selector: "*" requested: - google.rpc.context.ProjectContext - google.rpc.
context.OriginContext The above specifies that all methods in the API request
google.rpc.context.ProjectContext and google.rpc.context.OriginContext.
Available context types are defined in package google.rpc.context. This also
provides mechanism to allowlist any protobuf message extension that can be
sent in grpc metadata using “x-goog-ext--bin” and “x-goog-ext--jspb” format.
For example, list any service specific protobuf types that can appear in grpc
metadata as follows in your yaml file: Example: context: rules: - selector: "
google.example.library.v1.LibraryService.CreateBook"
allowed_request_extensions: - google.foo.v1.NewExtension
allowed_response_extensions: - google.foo.v1.NewExtension You can also specify
extension ID instead of fully qualified extension name here.
Corresponds to the JSON property context
2417 2418 2419 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2417 def context @context end |
#control ⇒ Google::Apis::ServiceusageV1beta1::Control
Selects and configures the service controller used by the service. Example:
control: environment: servicecontrol.googleapis.com
Corresponds to the JSON property control
2423 2424 2425 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2423 def control @control end |
#custom_error ⇒ Google::Apis::ServiceusageV1beta1::CustomError
Customize service error responses. For example, list any service specific
protobuf types that can appear in error detail lists of error responses.
Example: custom_error: types: - google.foo.v1.CustomError - google.foo.v1.
AnotherError
Corresponds to the JSON property customError
2431 2432 2433 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2431 def custom_error @custom_error end |
#documentation ⇒ Google::Apis::ServiceusageV1beta1::Documentation
Documentation provides the information for describing a service. Example:
documentation: summary: > The Google Calendar API gives access to most
calendar features. pages: - name: Overview content: (== include google/foo/
overview.md ==) - name: Tutorial content: (== include google/foo/tutorial.md ==
) subpages: - name: Java content: (== include google/foo/tutorial_java.md ==)
rules: - selector: google.calendar.Calendar.Get description: > ... - selector:
google.calendar.Calendar.Put description: > ... Documentation is provided in
markdown syntax. In addition to standard markdown features, definition lists,
tables and fenced code blocks are supported. Section headers can be provided
and are interpreted relative to the section nesting of the context where a
documentation fragment is embedded. Documentation from the IDL is merged with
documentation defined via the config at normalization time, where
documentation provided by config rules overrides IDL provided. A number of
constructs specific to the API platform are supported in documentation text.
In order to reference a proto element, the following notation can be used: [
fully.qualified.proto.name][] To override the display text used for the link,
this can be used: [display text][fully.qualified.proto.name] Text can be
excluded from doc using the following notation: (-- internal comment --) A few
directives are available in documentation. Note that directives must appear on
a single line to be properly identified. The include directive includes a
markdown file from an external source: (== include path/to/file ==) The
resource_for directive marks a message to be the resource of a collection in
REST view. If it is not specified, tools attempt to infer the resource from
the operations in a collection: (== resource_for v1.shelves.books ==) The
directive suppress_warning does not directly affect documentation and is
documented together with service config validation.
Corresponds to the JSON property documentation
2461 2462 2463 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2461 def documentation @documentation end |
#endpoints ⇒ Array<Google::Apis::ServiceusageV1beta1::Endpoint>
Configuration for network endpoints. If this is empty, then an endpoint with
the same name as the service is automatically generated to service all defined
APIs. WARNING: Defining any entries in the endpoints list disables the
automatic generation of default endpoint variations (e.g., service`.clients6.
google.com`, `content-`service`.googleapis.com`, and mTLS variants like
service.mtls.googleapis.com). To retain these default variations, you are
required to explicitly include your main service endpoint (e.g., myservice.
googleapis.com) in this list alongside any other custom endpoints (like REP,
GFE, etc.).
Corresponds to the JSON property endpoints
2474 2475 2476 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2474 def endpoints @endpoints end |
#enums ⇒ Array<Google::Apis::ServiceusageV1beta1::Enum>
A list of all enum types included in this API service. Enums referenced
directly or indirectly by the apis are automatically included. Enums which
are not referenced but shall be included should be listed here by name by the
configuration author. Example: enums: - name: google.someapi.v1.SomeEnum
Corresponds to the JSON property enums
2482 2483 2484 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2482 def enums @enums end |
#http ⇒ Google::Apis::ServiceusageV1beta1::Http
Defines the HTTP configuration for an API service. It contains a list of
HttpRule, each specifying the mapping of an RPC method to one or more HTTP
REST API methods.
Corresponds to the JSON property http
2489 2490 2491 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2489 def http @http end |
#id ⇒ String
A unique ID for a specific instance of this message, typically assigned by the
client for tracking purpose. Must be no longer than 63 characters and only
lower case letters, digits, '.', '_' and '-' are allowed. If empty, the server
may choose to generate one instead.
Corresponds to the JSON property id
2497 2498 2499 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2497 def id @id end |
#logging ⇒ Google::Apis::ServiceusageV1beta1::Logging
Logging configuration of the service. The following example shows how to
configure logs to be sent to the producer and consumer projects. In the
example, the activity_history log is sent to both the producer and consumer
projects, whereas the purchase_history log is only sent to the producer
project. monitored_resources: - type: library.googleapis.com/branch labels: -
key: /city description: The city where the library branch is located in. - key:
/name description: The name of the branch. logs: - name: activity_history
labels: - key: /customer_id - name: purchase_history logging:
producer_destinations: - monitored_resource: library.googleapis.com/branch
logs: - activity_history - purchase_history consumer_destinations: -
monitored_resource: library.googleapis.com/branch logs: - activity_history
Corresponds to the JSON property logging
2512 2513 2514 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2512 def logging @logging end |
#logs ⇒ Array<Google::Apis::ServiceusageV1beta1::LogDescriptor>
Defines the logs used by this service.
Corresponds to the JSON property logs
2517 2518 2519 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2517 def logs @logs end |
#metrics ⇒ Array<Google::Apis::ServiceusageV1beta1::MetricDescriptor>
Defines the metrics used by this service.
Corresponds to the JSON property metrics
2522 2523 2524 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2522 def metrics @metrics end |
#monitored_resources ⇒ Array<Google::Apis::ServiceusageV1beta1::MonitoredResourceDescriptor>
Defines the monitored resources used by this service. This is required by the
Service.monitoring and Service.logging configurations.
Corresponds to the JSON property monitoredResources
2528 2529 2530 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2528 def monitored_resources @monitored_resources end |
#monitoring ⇒ Google::Apis::ServiceusageV1beta1::Monitoring
Monitoring configuration of the service. The example below shows how to
configure monitored resources and metrics for monitoring. In the example, a
monitored resource and two metrics are defined. The library.googleapis.com/
book/returned_count metric is sent to both producer and consumer projects,
whereas the library.googleapis.com/book/num_overdue metric is only sent to
the consumer project. monitored_resources: - type: library.googleapis.com/
Branch display_name: "Library Branch" description: "A branch of a library."
launch_stage: GA labels: - key: resource_container description: "The Cloud
container (ie. project id) for the Branch." - key: location description: "The
location of the library branch." - key: branch_id description: "The id of the
branch." metrics: - name: library.googleapis.com/book/returned_count
display_name: "Books Returned" description: "The count of books that have been
returned." launch_stage: GA metric_kind: DELTA value_type: INT64 unit: "1"
labels: - key: customer_id description: "The id of the customer." - name:
library.googleapis.com/book/num_overdue display_name: "Books Overdue"
description: "The current number of overdue books." launch_stage: GA
metric_kind: GAUGE value_type: INT64 unit: "1" labels: - key: customer_id
description: "The id of the customer." monitoring: producer_destinations: -
monitored_resource: library.googleapis.com/Branch metrics: - library.
googleapis.com/book/returned_count consumer_destinations: - monitored_resource:
library.googleapis.com/Branch metrics: - library.googleapis.com/book/
returned_count - library.googleapis.com/book/num_overdue
Corresponds to the JSON property monitoring
2554 2555 2556 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2554 def monitoring @monitoring end |
#name ⇒ String
The service name, which is a DNS-like logical identifier for the service, such
as calendar.googleapis.com. The service name typically goes through DNS
verification to make sure the owner of the service also owns the DNS name.
Corresponds to the JSON property name
2561 2562 2563 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2561 def name @name end |
#producer_project_id ⇒ String
The Google project that owns this service.
Corresponds to the JSON property producerProjectId
2566 2567 2568 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2566 def producer_project_id @producer_project_id end |
#publishing ⇒ Google::Apis::ServiceusageV1beta1::Publishing
This message configures the settings for publishing Google Cloud Client
libraries
generated from the service config.
Corresponds to the JSON property publishing
2573 2574 2575 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2573 def publishing @publishing end |
#quota ⇒ Google::Apis::ServiceusageV1beta1::Quota
Quota configuration helps to achieve fairness and budgeting in service usage.
The metric based quota configuration works this way: - The service
configuration defines a set of metrics. - For API calls, the quota.
metric_rules maps methods to metrics with corresponding costs. - The quota.
limits defines limits on the metrics, which will be used for quota checks at
runtime. An example quota configuration in yaml format: quota: limits: - name:
apiWriteQpsPerProject metric: library.googleapis.com/write_calls unit: "1/min/
project" # rate limit for consumer projects values: STANDARD: 10000 (The
metric rules bind all methods to the read_calls metric, except for the
UpdateBook and DeleteBook methods. These two methods are mapped to the
write_calls metric, with the UpdateBook method consuming at twice rate as the
DeleteBook method.) metric_rules: - selector: "*" metric_costs: library.
googleapis.com/read_calls: 1 - selector: google.example.library.v1.
LibraryService.UpdateBook metric_costs: library.googleapis.com/write_calls: 2 -
selector: google.example.library.v1.LibraryService.DeleteBook metric_costs:
library.googleapis.com/write_calls: 1 Corresponding Metric definition: metrics:
- name: library.googleapis.com/read_calls display_name: Read requests
metric_kind: DELTA value_type: INT64 - name: library.googleapis.com/
write_calls display_name: Write requests metric_kind: DELTA value_type: INT64
Corresponds to the JSON property
quota
2596 2597 2598 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2596 def quota @quota end |
#source_info ⇒ Google::Apis::ServiceusageV1beta1::SourceInfo
Source information used to create a Service Config
Corresponds to the JSON property sourceInfo
2601 2602 2603 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2601 def source_info @source_info end |
#system_parameters ⇒ Google::Apis::ServiceusageV1beta1::SystemParameters
System parameter configuration A system parameter is a special kind of
parameter defined by the API system, not by an individual API. It is typically
mapped to an HTTP header and/or a URL query parameter. This configuration
specifies which methods change the names of the system parameters.
Corresponds to the JSON property systemParameters
2609 2610 2611 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2609 def system_parameters @system_parameters end |
#system_types ⇒ Array<Google::Apis::ServiceusageV1beta1::Type>
A list of all proto message types included in this API service. It serves
similar purpose as [google.api.Service.types], except that these types are not
needed by user-defined APIs. Therefore, they will not show up in the generated
discovery doc. This field should only be used to define system APIs in ESF.
Corresponds to the JSON property systemTypes
2617 2618 2619 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2617 def system_types @system_types end |
#title ⇒ String
The product title for this service, it is the name displayed in Google Cloud
Console.
Corresponds to the JSON property title
2623 2624 2625 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2623 def title @title end |
#types ⇒ Array<Google::Apis::ServiceusageV1beta1::Type>
A list of all proto message types included in this API service. Types
referenced directly or indirectly by the apis are automatically included.
Messages which are not referenced but shall be included, such as types used by
the google.protobuf.Any type, should be listed here by name by the
configuration author. Example: types: - name: google.protobuf.Int32
Corresponds to the JSON property types
2632 2633 2634 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2632 def types @types end |
#usage ⇒ Google::Apis::ServiceusageV1beta1::Usage
Configuration controlling usage of a service.
Corresponds to the JSON property usage
2637 2638 2639 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2637 def usage @usage end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 2656 2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2644 def update!(**args) @apis = args[:apis] if args.key?(:apis) @aspects = args[:aspects] if args.key?(:aspects) @authentication = args[:authentication] if args.key?(:authentication) @backend = args[:backend] if args.key?(:backend) @billing = args[:billing] if args.key?(:billing) @config_version = args[:config_version] if args.key?(:config_version) @context = args[:context] if args.key?(:context) @control = args[:control] if args.key?(:control) @custom_error = args[:custom_error] if args.key?(:custom_error) @documentation = args[:documentation] if args.key?(:documentation) @endpoints = args[:endpoints] if args.key?(:endpoints) @enums = args[:enums] if args.key?(:enums) @http = args[:http] if args.key?(:http) @id = args[:id] if args.key?(:id) @logging = args[:logging] if args.key?(:logging) @logs = args[:logs] if args.key?(:logs) @metrics = args[:metrics] if args.key?(:metrics) @monitored_resources = args[:monitored_resources] if args.key?(:monitored_resources) @monitoring = args[:monitoring] if args.key?(:monitoring) @name = args[:name] if args.key?(:name) @producer_project_id = args[:producer_project_id] if args.key?(:producer_project_id) @publishing = args[:publishing] if args.key?(:publishing) @quota = args[:quota] if args.key?(:quota) @source_info = args[:source_info] if args.key?(:source_info) @system_parameters = args[:system_parameters] if args.key?(:system_parameters) @system_types = args[:system_types] if args.key?(:system_types) @title = args[:title] if args.key?(:title) @types = args[:types] if args.key?(:types) @usage = args[:usage] if args.key?(:usage) end |