Class: Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV1Service
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV1Service
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
A service that is available for use by the consumer.
Instance Attribute Summary collapse
-
#config ⇒ Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV1ServiceConfig
The configuration of the service.
-
#name ⇒ String
The resource name of the consumer and service.
-
#parent ⇒ String
The resource name of the consumer.
-
#state ⇒ String
Whether or not the service has been enabled for use by the consumer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleApiServiceusageV1Service
constructor
A new instance of GoogleApiServiceusageV1Service.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleApiServiceusageV1Service
Returns a new instance of GoogleApiServiceusageV1Service.
2708 2709 2710 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2708 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config ⇒ Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV1ServiceConfig
The configuration of the service.
Corresponds to the JSON property config
2690 2691 2692 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2690 def config @config end |
#name ⇒ String
The resource name of the consumer and service. A valid name would be: -
projects/123/services/serviceusage.googleapis.com
Corresponds to the JSON property name
2696 2697 2698 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2696 def name @name end |
#parent ⇒ String
The resource name of the consumer. A valid name would be: - projects/123
Corresponds to the JSON property parent
2701 2702 2703 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2701 def parent @parent end |
#state ⇒ String
Whether or not the service has been enabled for use by the consumer.
Corresponds to the JSON property state
2706 2707 2708 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2706 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2713 2714 2715 2716 2717 2718 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2713 def update!(**args) @config = args[:config] if args.key?(:config) @name = args[:name] if args.key?(:name) @parent = args[:parent] if args.key?(:parent) @state = args[:state] if args.key?(:state) end |