Class: Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2alphaAnalysis

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

A message to group the analysis information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleApiServiceusageV2alphaAnalysis

Returns a new instance of GoogleApiServiceusageV2alphaAnalysis.



2948
2949
2950
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2948

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_resultGoogle::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2alphaAnalysisResult

An analysis result including blockers and warnings. Corresponds to the JSON property analysisResult



2929
2930
2931
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2929

def analysis_result
  @analysis_result
end

#analysis_typeString

Output only. The type of analysis. Corresponds to the JSON property analysisType

Returns:

  • (String)


2934
2935
2936
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2934

def analysis_type
  @analysis_type
end

#display_nameString

Output only. The user friendly display name of the analysis type. E.g. service dependency analysis, service resource usage analysis, etc. Corresponds to the JSON property displayName

Returns:

  • (String)


2940
2941
2942
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2940

def display_name
  @display_name
end

#serviceString

The names of the service that has analysis result of warnings or blockers. Example: services/storage.googleapis.com. Corresponds to the JSON property service

Returns:

  • (String)


2946
2947
2948
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2946

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2953
2954
2955
2956
2957
2958
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2953

def update!(**args)
  @analysis_result = args[:analysis_result] if args.key?(:analysis_result)
  @analysis_type = args[:analysis_type] if args.key?(:analysis_type)
  @display_name = args[:display_name] if args.key?(:display_name)
  @service = args[:service] if args.key?(:service)
end