Class: Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2alphaAnalysisResult
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2alphaAnalysisResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
An analysis result including blockers and warnings.
Instance Attribute Summary collapse
-
#blockers ⇒ Array<Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2alphaImpact>
Blocking information that would prevent the policy changes at runtime.
-
#warnings ⇒ Array<Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2alphaImpact>
Warning information indicating that the policy changes might be unsafe, but will not block the changes at runtime.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleApiServiceusageV2alphaAnalysisResult
constructor
A new instance of GoogleApiServiceusageV2alphaAnalysisResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleApiServiceusageV2alphaAnalysisResult
Returns a new instance of GoogleApiServiceusageV2alphaAnalysisResult.
2976 2977 2978 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2976 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blockers ⇒ Array<Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2alphaImpact>
Blocking information that would prevent the policy changes at runtime.
Corresponds to the JSON property blockers
2968 2969 2970 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2968 def blockers @blockers end |
#warnings ⇒ Array<Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2alphaImpact>
Warning information indicating that the policy changes might be unsafe, but
will not block the changes at runtime.
Corresponds to the JSON property warnings
2974 2975 2976 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2974 def warnings @warnings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2981 2982 2983 2984 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2981 def update!(**args) @blockers = args[:blockers] if args.key?(:blockers) @warnings = args[:warnings] if args.key?(:warnings) end |