Class: Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2alphaConsumerPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

Consumer Policy is a set of rules that define what services or service groups can be used for a cloud resource hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleApiServiceusageV2alphaConsumerPolicy

Returns a new instance of GoogleApiServiceusageV2alphaConsumerPolicy.



3073
3074
3075
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3073

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Annotations is an unstructured key-value map stored with a policy that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. AIP- 128 Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


3040
3041
3042
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3040

def annotations
  @annotations
end

#create_timeString

Output only. The time the policy was created. For singleton policies, this is the first touch of the policy. Corresponds to the JSON property createTime

Returns:

  • (String)


3046
3047
3048
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3046

def create_time
  @create_time
end

#enable_rulesArray<Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2alphaEnableRule>

Enable rules define usable services, groups, and categories. There can currently be at most one EnableRule. This restriction will be lifted in later releases. Corresponds to the JSON property enableRules



3053
3054
3055
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3053

def enable_rules
  @enable_rules
end

#etagString

Output only. An opaque tag indicating the current version of the policy, used for concurrency control. Corresponds to the JSON property etag

Returns:

  • (String)


3059
3060
3061
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3059

def etag
  @etag
end

#nameString

Output only. The resource name of the policy. Only the default policy is supported: projects/12345/consumerPolicies/default, folders/12345/ consumerPolicies/default, organizations/12345/consumerPolicies/default. Corresponds to the JSON property name

Returns:

  • (String)


3066
3067
3068
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3066

def name
  @name
end

#update_timeString

Output only. The time the policy was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3071
3072
3073
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3071

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3078
3079
3080
3081
3082
3083
3084
3085
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3078

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @create_time = args[:create_time] if args.key?(:create_time)
  @enable_rules = args[:enable_rules] if args.key?(:enable_rules)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end