Class: Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2alphaImpact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

A message to group impacts of updating a policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleApiServiceusageV2alphaImpact

Returns a new instance of GoogleApiServiceusageV2alphaImpact.



3134
3135
3136
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3134

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailString

Output only. User friendly impact detail in a free form message. Corresponds to the JSON property detail

Returns:

  • (String)


3115
3116
3117
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3115

def detail
  @detail
end

#impact_typeString

Output only. The type of impact. Corresponds to the JSON property impactType

Returns:

  • (String)


3120
3121
3122
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3120

def impact_type
  @impact_type
end

#parentString

The parent resource that the analysis is based on and the service name that the analysis is for. Example: projects/100/services/compute.googleapis.com, folders/101/services/compute.googleapis.comandorganizations/102/services/ compute.googleapis.com. Usually, the parent resource here is same as the parent resource of the analyzed policy. However, for some analysis types, the parent can be different. For example, for resource existence analysis, if the parent resource of the analyzed policy is a folder or an organization, the parent resource here can still be the project that contains the resources. Corresponds to the JSON propertyparent`

Returns:

  • (String)


3132
3133
3134
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3132

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3139
3140
3141
3142
3143
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3139

def update!(**args)
  @detail = args[:detail] if args.key?(:detail)
  @impact_type = args[:impact_type] if args.key?(:impact_type)
  @parent = args[:parent] if args.key?(:parent)
end