Class: Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaAnalysis

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

A message to group the analysis information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleApiServiceusageV2betaAnalysis

Returns a new instance of GoogleApiServiceusageV2betaAnalysis.



3050
3051
3052
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3050

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_resultGoogle::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaAnalysisResult

An analysis result including blockers and warnings. Corresponds to the JSON property analysisResult



3031
3032
3033
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3031

def analysis_result
  @analysis_result
end

#analysis_typeString

Output only. The type of analysis. Corresponds to the JSON property analysisType

Returns:

  • (String)


3036
3037
3038
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3036

def analysis_type
  @analysis_type
end

#display_nameString

Output only. The user friendly display name of the analysis type. E.g. service dependency analysis, service resource usage analysis, etc. Corresponds to the JSON property displayName

Returns:

  • (String)


3042
3043
3044
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3042

def display_name
  @display_name
end

#serviceString

The names of the service that has analysis result of warnings or blockers. Example: services/storage.googleapis.com. Corresponds to the JSON property service

Returns:

  • (String)


3048
3049
3050
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3048

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3055
3056
3057
3058
3059
3060
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3055

def update!(**args)
  @analysis_result = args[:analysis_result] if args.key?(:analysis_result)
  @analysis_type = args[:analysis_type] if args.key?(:analysis_type)
  @display_name = args[:display_name] if args.key?(:display_name)
  @service = args[:service] if args.key?(:service)
end