Class: Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaConsumerPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

Consumer Policy is a set of rules that define what services or service groups can be used for a cloud resource hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleApiServiceusageV2betaConsumerPolicy

Returns a new instance of GoogleApiServiceusageV2betaConsumerPolicy.



3295
3296
3297
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3295

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the policy was created. For singleton policies, this is the first touch of the policy. Corresponds to the JSON property createTime

Returns:

  • (String)


3268
3269
3270
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3268

def create_time
  @create_time
end

#enable_rulesArray<Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaEnableRule>

Enable rules define usable services, groups, and categories. There can currently be at most one EnableRule. This restriction will be lifted in later releases. Corresponds to the JSON property enableRules



3275
3276
3277
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3275

def enable_rules
  @enable_rules
end

#etagString

An opaque tag indicating the current version of the policy, used for concurrency control. Corresponds to the JSON property etag

Returns:

  • (String)


3281
3282
3283
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3281

def etag
  @etag
end

#nameString

Output only. The resource name of the policy. Only the default policy is supported: projects/12345/consumerPolicies/default, folders/12345/ consumerPolicies/default, organizations/12345/consumerPolicies/default. Corresponds to the JSON property name

Returns:

  • (String)


3288
3289
3290
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3288

def name
  @name
end

#update_timeString

Output only. The time the policy was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3293
3294
3295
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3293

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3300
3301
3302
3303
3304
3305
3306
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3300

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @enable_rules = args[:enable_rules] if args.key?(:enable_rules)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end