Class: Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaImpact
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaImpact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
A message to group impacts of updating a policy.
Instance Attribute Summary collapse
-
#detail ⇒ String
Output only.
-
#impact_type ⇒ String
Output only.
-
#missing_dependency ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleApiServiceusageV2betaImpact
constructor
A new instance of GoogleApiServiceusageV2betaImpact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleApiServiceusageV2betaImpact
Returns a new instance of GoogleApiServiceusageV2betaImpact.
3351 3352 3353 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3351 def initialize(**args) update!(**args) end |
Instance Attribute Details
#detail ⇒ String
Output only. User friendly impact detail in a free form message.
Corresponds to the JSON property detail
3336 3337 3338 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3336 def detail @detail end |
#impact_type ⇒ String
Output only. The type of impact.
Corresponds to the JSON property impactType
3341 3342 3343 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3341 def impact_type @impact_type end |
#missing_dependency ⇒ String
Output only. This field will be populated only for the
DEPENDENCY_MISSING_DEPENDENCIES impact type. Example: services/compute.
googleapis.com. Impact.detail will be in format : missing service dependency:
missing_dependency.
Corresponds to the JSON property missingDependency
3349 3350 3351 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3349 def missing_dependency @missing_dependency end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3356 3357 3358 3359 3360 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3356 def update!(**args) @detail = args[:detail] if args.key?(:detail) @impact_type = args[:impact_type] if args.key?(:impact_type) @missing_dependency = args[:missing_dependency] if args.key?(:missing_dependency) end |