Class: Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaMcpPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaMcpPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
MCP Consumer Policy is a set of rules that define MCP related policy for a cloud resource hierarchy.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
An opaque tag indicating the current version of the policy, used for concurrency control.
-
#mcp_enable_rules ⇒ Array<Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaMcpEnableRule>
McpEnableRules contains MCP enablement related rules.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleApiServiceusageV2betaMcpPolicy
constructor
A new instance of GoogleApiServiceusageV2betaMcpPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleApiServiceusageV2betaMcpPolicy
Returns a new instance of GoogleApiServiceusageV2betaMcpPolicy.
3417 3418 3419 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3417 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the policy was created. For singleton policies (such as
the default policy), this is the first touch of the policy.
Corresponds to the JSON property createTime
3391 3392 3393 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3391 def create_time @create_time end |
#etag ⇒ String
An opaque tag indicating the current version of the policy, used for
concurrency control.
Corresponds to the JSON property etag
3397 3398 3399 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3397 def etag @etag end |
#mcp_enable_rules ⇒ Array<Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaMcpEnableRule>
McpEnableRules contains MCP enablement related rules.
Corresponds to the JSON property mcpEnableRules
3402 3403 3404 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3402 def mcp_enable_rules @mcp_enable_rules end |
#name ⇒ String
Output only. The resource name of the policy. Only the default policy is
supported. We allow the following formats: projects/PROJECT_NUMBER/
mcpPolicies/default, projects/PROJECT_ID/mcpPolicies/default, folders/
FOLDER_ID/mcpPolicies/default, organizations/ORG_ID/mcpPolicies/default.
Corresponds to the JSON property name
3410 3411 3412 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3410 def name @name end |
#update_time ⇒ String
Output only. The time the policy was last updated.
Corresponds to the JSON property updateTime
3415 3416 3417 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3415 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3422 3423 3424 3425 3426 3427 3428 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3422 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @mcp_enable_rules = args[:mcp_enable_rules] if args.key?(:mcp_enable_rules) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |