Class: Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaMcpService
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaMcpService
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
McpService contains the service names that are enabled for MCP.
Instance Attribute Summary collapse
-
#service ⇒ String
The names of the services that are enabled for MCP.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleApiServiceusageV2betaMcpService
constructor
A new instance of GoogleApiServiceusageV2betaMcpService.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleApiServiceusageV2betaMcpService
Returns a new instance of GoogleApiServiceusageV2betaMcpService.
3309 3310 3311 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3309 def initialize(**args) update!(**args) end |
Instance Attribute Details
#service ⇒ String
The names of the services that are enabled for MCP. Example: services/library-
example.googleapis.com
Corresponds to the JSON property service
3307 3308 3309 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3307 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3314 3315 3316 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3314 def update!(**args) @service = args[:service] if args.key?(:service) end |