Class: Google::Apis::ServiceusageV1beta1::Impact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

A message to group impacts of updating a policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Impact

Returns a new instance of Impact.



3740
3741
3742
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3740

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailString

Output only. User friendly impact detail in a free form message. Corresponds to the JSON property detail

Returns:

  • (String)


3725
3726
3727
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3725

def detail
  @detail
end

#impact_typeString

Output only. The type of impact. Corresponds to the JSON property impactType

Returns:

  • (String)


3730
3731
3732
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3730

def impact_type
  @impact_type
end

#missing_dependencyString

Output only. This field will be populated only for the DEPENDENCY_MISSING_DEPENDENCIES impact type. Example: services/compute. googleapis.com. Impact.detail will be in format : missing service dependency: missing_dependency. Corresponds to the JSON property missingDependency

Returns:

  • (String)


3738
3739
3740
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3738

def missing_dependency
  @missing_dependency
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3745
3746
3747
3748
3749
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3745

def update!(**args)
  @detail = args[:detail] if args.key?(:detail)
  @impact_type = args[:impact_type] if args.key?(:impact_type)
  @missing_dependency = args[:missing_dependency] if args.key?(:missing_dependency)
end