Class: Google::Apis::ServiceusageV1beta1::ImportConsumerOverridesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

Request message for ImportConsumerOverrides

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImportConsumerOverridesRequest

Returns a new instance of ImportConsumerOverridesRequest.



3905
3906
3907
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3905

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#forceBoolean Also known as: force?

Whether to force the creation of the quota overrides. Setting the force parameter to 'true' ignores all quota safety checks that would fail the request. QuotaSafetyCheck lists all such validations. If force is set to true, it is recommended to include a case id in "X-Goog-Request-Reason" header when sending the request. Corresponds to the JSON property force

Returns:

  • (Boolean)


3887
3888
3889
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3887

def force
  @force
end

#force_onlyArray<String>

The list of quota safety checks to ignore before the override mutation. Unlike 'force' field that ignores all the quota safety checks, the 'force_only' field ignores only the specified checks; other checks are still enforced. The 'force' and 'force_only' fields cannot both be set. If force_only is specified, it is recommended to include a case id in "X-Goog-Request-Reason" header when sending the request. Corresponds to the JSON property forceOnly

Returns:

  • (Array<String>)


3898
3899
3900
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3898

def force_only
  @force_only
end

#inline_sourceGoogle::Apis::ServiceusageV1beta1::OverrideInlineSource

Import data embedded in the request message Corresponds to the JSON property inlineSource



3903
3904
3905
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3903

def inline_source
  @inline_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3910
3911
3912
3913
3914
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3910

def update!(**args)
  @force = args[:force] if args.key?(:force)
  @force_only = args[:force_only] if args.key?(:force_only)
  @inline_source = args[:inline_source] if args.key?(:inline_source)
end