Class: Google::Apis::ServiceusageV1beta1::ListOperationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::ListOperationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
The response message for Operations.ListOperations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The standard List next-page token.
-
#operations ⇒ Array<Google::Apis::ServiceusageV1beta1::Operation>
A list of operations that matches the specified filter in the request.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListOperationsResponse
constructor
A new instance of ListOperationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListOperationsResponse
Returns a new instance of ListOperationsResponse.
4017 4018 4019 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4017 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
4002 4003 4004 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4002 def next_page_token @next_page_token end |
#operations ⇒ Array<Google::Apis::ServiceusageV1beta1::Operation>
A list of operations that matches the specified filter in the request.
Corresponds to the JSON property operations
4007 4008 4009 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4007 def operations @operations end |
#unreachable ⇒ Array<String>
Unordered list. Unreachable resources. Populated when the request sets
ListOperationsRequest.return_partial_success and reads across collections.
For example, when attempting to list all resources across all supported
locations.
Corresponds to the JSON property unreachable
4015 4016 4017 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4015 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4022 4023 4024 4025 4026 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4022 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @operations = args[:operations] if args.key?(:operations) @unreachable = args[:unreachable] if args.key?(:unreachable) end |