Class: Google::Apis::ServiceusageV1beta1::McpService

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

McpService contains the service names that are enabled for MCP.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ McpService

Returns a new instance of McpService.



4292
4293
4294
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4292

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#serviceString

The names of the services that are enabled for MCP. Example: services/library- example.googleapis.com Corresponds to the JSON property service

Returns:

  • (String)


4290
4291
4292
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4290

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4297
4298
4299
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4297

def update!(**args)
  @service = args[:service] if args.key?(:service)
end