Class: Google::Apis::ServiceusageV1beta1::MethodPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

Defines policies applying to an RPC method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MethodPolicy

Returns a new instance of MethodPolicy.



4298
4299
4300
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4298

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#request_policiesArray<Google::Apis::ServiceusageV1beta1::FieldPolicy>

Policies that are applicable to the request message. Corresponds to the JSON property requestPolicies



4288
4289
4290
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4288

def request_policies
  @request_policies
end

#selectorString

Selects a method to which these policies should be enforced, for example, " google.pubsub.v1.Subscriber.CreateSubscription". Refer to selector for syntax details. NOTE: This field must not be set in the proto annotation. It will be automatically filled by the service config compiler . Corresponds to the JSON property selector

Returns:

  • (String)


4296
4297
4298
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4296

def selector
  @selector
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4303
4304
4305
4306
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4303

def update!(**args)
  @request_policies = args[:request_policies] if args.key?(:request_policies)
  @selector = args[:selector] if args.key?(:selector)
end