Class: Google::Apis::ServiceusageV1beta1::MethodSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

Describes the generator configuration for a method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MethodSettings

Returns a new instance of MethodSettings.



4435
4436
4437
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4435

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_populated_fieldsArray<String>

List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info). format. Currently supported format: UUID4. Example of a YAML configuration: publishing: method_settings: - selector: google.example.v1.ExampleService. CreateExample auto_populated_fields: - request_id Corresponds to the JSON property autoPopulatedFields

Returns:

  • (Array<String>)


4411
4412
4413
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4411

def auto_populated_fields
  @auto_populated_fields
end

#batchingGoogle::Apis::ServiceusageV1beta1::BatchingConfigProto

BatchingConfigProto defines the batching configuration for an API method. Corresponds to the JSON property batching



4416
4417
4418
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4416

def batching
  @batching
end

#long_runningGoogle::Apis::ServiceusageV1beta1::LongRunning

Describes settings to use when generating API methods that use the long- running operation pattern. All default values below are from those used in the client library generators (e.g. Java). Corresponds to the JSON property longRunning



4425
4426
4427
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4425

def long_running
  @long_running
end

#selectorString

The fully qualified name of the method, for which the options below apply. This is used to find the method to apply the options. Example: publishing: method_settings: - selector: google.storage.control.v2.StorageControl. CreateFolder # method settings for CreateFolder... Corresponds to the JSON property selector

Returns:

  • (String)


4433
4434
4435
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4433

def selector
  @selector
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4440
4441
4442
4443
4444
4445
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4440

def update!(**args)
  @auto_populated_fields = args[:auto_populated_fields] if args.key?(:auto_populated_fields)
  @batching = args[:batching] if args.key?(:batching)
  @long_running = args[:long_running] if args.key?(:long_running)
  @selector = args[:selector] if args.key?(:selector)
end