Class: Google::Apis::ServiceusageV1beta1::Option
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::Option
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
A protocol buffer option, which can be attached to a message, field, enumeration, etc. New usages of this message as an alternative to FileOptions, MessageOptions, FieldOptions, EnumOptions, EnumValueOptions, ServiceOptions, or MethodOptions are strongly discouraged.
Instance Attribute Summary collapse
-
#name ⇒ String
The option's name.
-
#value ⇒ Hash<String,Object>
The option's value packed in an Any message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Option
constructor
A new instance of Option.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Option
Returns a new instance of Option.
5079 5080 5081 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5079 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The option's name. For protobuf built-in options (options defined in
descriptor.proto), this is the short name. For example, "map_entry". For
custom options, it should be the fully-qualified name. For example, "google.
api.http".
Corresponds to the JSON property name
5069 5070 5071 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5069 def name @name end |
#value ⇒ Hash<String,Object>
The option's value packed in an Any message. If the value is a primitive, the
corresponding wrapper type defined in google/protobuf/wrappers.proto should be
used. If the value is an enum, it should be stored as an int32 value using the
google.protobuf.Int32Value type.
Corresponds to the JSON property value
5077 5078 5079 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5077 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5084 5085 5086 5087 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5084 def update!(**args) @name = args[:name] if args.key?(:name) @value = args[:value] if args.key?(:value) end |