Class: Google::Apis::ServiceusageV1beta1::Page
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::Page
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
Represents a documentation page. A page can contain subpages to represent nested documentation set structure.
Instance Attribute Summary collapse
-
#content ⇒ String
The Markdown content of the page.
-
#name ⇒ String
The name of the page.
-
#subpages ⇒ Array<Google::Apis::ServiceusageV1beta1::Page>
Subpages of this page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Page
constructor
A new instance of Page.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Page
Returns a new instance of Page.
5147 5148 5149 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5147 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content ⇒ String
The Markdown content of the page. You can use (== include `path` ==) to
include content from a Markdown file. The content can be used to produce the
documentation page such as HTML format page.
Corresponds to the JSON property content
5128 5129 5130 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5128 def content @content end |
#name ⇒ String
The name of the page. It will be used as an identity of the page to generate
URI of the page, text of the link to this page in navigation, etc. The full
page name (start from the root page name to this page concatenated with .)
can be used as reference to the page in your documentation. For example: pages:
- name: Tutorial content: (== include tutorial.md ==) subpages: - name: Java
content: (== include tutorial_java.md ==) You can reference
Javapage using Markdown reference link syntax:Java. Corresponds to the JSON propertyname
5139 5140 5141 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5139 def name @name end |
#subpages ⇒ Array<Google::Apis::ServiceusageV1beta1::Page>
Subpages of this page. The order of subpages specified here will be honored in
the generated docset.
Corresponds to the JSON property subpages
5145 5146 5147 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5145 def subpages @subpages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5152 5153 5154 5155 5156 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5152 def update!(**args) @content = args[:content] if args.key?(:content) @name = args[:name] if args.key?(:name) @subpages = args[:subpages] if args.key?(:subpages) end |