Class: Google::Apis::ServiceusageV1beta1::QuotaBucket

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

A quota bucket is a quota provisioning unit for a specific set of dimensions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuotaBucket

Returns a new instance of QuotaBucket.



5474
5475
5476
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5474

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_overrideGoogle::Apis::ServiceusageV1beta1::QuotaOverride

A quota override Corresponds to the JSON property adminOverride



5429
5430
5431
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5429

def admin_override
  @admin_override
end

#consumer_overrideGoogle::Apis::ServiceusageV1beta1::QuotaOverride

A quota override Corresponds to the JSON property consumerOverride



5434
5435
5436
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5434

def consumer_override
  @consumer_override
end

#default_limitFixnum

The default limit of this quota bucket, as specified by the service configuration. Corresponds to the JSON property defaultLimit

Returns:

  • (Fixnum)


5440
5441
5442
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5440

def default_limit
  @default_limit
end

#dimensionsHash<String,String>

The dimensions of this quota bucket. If this map is empty, this is the global bucket, which is the default quota value applied to all requests that do not have a more specific override. If this map is nonempty, the default limit, effective limit, and quota overrides apply only to requests that have the dimensions given in the map. For example, if the map has key region and value us-east-1, then the specified effective limit is only effective in that region, and the specified overrides apply only in that region. Corresponds to the JSON property dimensions

Returns:

  • (Hash<String,String>)


5451
5452
5453
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5451

def dimensions
  @dimensions
end

#effective_limitFixnum

The effective limit of this quota bucket. Equal to default_limit if there are no overrides. Corresponds to the JSON property effectiveLimit

Returns:

  • (Fixnum)


5457
5458
5459
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5457

def effective_limit
  @effective_limit
end

#producer_overrideGoogle::Apis::ServiceusageV1beta1::QuotaOverride

A quota override Corresponds to the JSON property producerOverride



5462
5463
5464
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5462

def producer_override
  @producer_override
end

#producer_quota_policyGoogle::Apis::ServiceusageV1beta1::ProducerQuotaPolicy

Quota policy created by service producer. Corresponds to the JSON property producerQuotaPolicy



5467
5468
5469
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5467

def producer_quota_policy
  @producer_quota_policy
end

#rollout_infoGoogle::Apis::ServiceusageV1beta1::RolloutInfo

[Output only] Rollout information of a quota. Corresponds to the JSON property rolloutInfo



5472
5473
5474
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5472

def rollout_info
  @rollout_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5479
5480
5481
5482
5483
5484
5485
5486
5487
5488
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5479

def update!(**args)
  @admin_override = args[:admin_override] if args.key?(:admin_override)
  @consumer_override = args[:consumer_override] if args.key?(:consumer_override)
  @default_limit = args[:default_limit] if args.key?(:default_limit)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @effective_limit = args[:effective_limit] if args.key?(:effective_limit)
  @producer_override = args[:producer_override] if args.key?(:producer_override)
  @producer_quota_policy = args[:producer_quota_policy] if args.key?(:producer_quota_policy)
  @rollout_info = args[:rollout_info] if args.key?(:rollout_info)
end