Class: Google::Apis::ServiceusageV1beta1::QuotaOverride
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::QuotaOverride
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
A quota override
Instance Attribute Summary collapse
-
#admin_override_ancestor ⇒ String
The resource name of the ancestor that requested the override.
-
#dimensions ⇒ Hash<String,String>
If this map is nonempty, then this override applies only to specific values for dimensions defined in the limit unit.
-
#metric ⇒ String
The name of the metric to which this override applies.
-
#name ⇒ String
The resource name of the override.
-
#override_value ⇒ Fixnum
The overriding quota limit value.
-
#unit ⇒ String
The limit unit of the limit to which this override applies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QuotaOverride
constructor
A new instance of QuotaOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QuotaOverride
Returns a new instance of QuotaOverride.
5659 5660 5661 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5659 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_override_ancestor ⇒ String
The resource name of the ancestor that requested the override. For example:
organizations/12345 or folders/67890. Used by admin overrides only.
Corresponds to the JSON property adminOverrideAncestor
5607 5608 5609 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5607 def admin_override_ancestor @admin_override_ancestor end |
#dimensions ⇒ Hash<String,String>
If this map is nonempty, then this override applies only to specific values
for dimensions defined in the limit unit. For example, an override on a limit
with the unit 1/project/regioncould contain an entry with the key `
region` and the value `us-east-1`; the override is only applied to quota
consumed in that region. This map has the following restrictions: * Keys that
are not defined in the limit's unit are not valid keys. Any string appearing
inbracketsin the unit (besidesprojectoruser``) is a defined key.
projectis not a valid key; the project is already specified in the parent resource name. *useris not a valid key; the API does not support quota overrides that apply only to a specific user. * Ifregionappears as a key, its value must be a valid Cloud region. * Ifzoneappears as a key, its value must be a valid Cloud zone. * If any valid key other thanregionorzoneappears in the map, then all valid keys other thanregionorzonemust also appear in the map. Corresponds to the JSON propertydimensions
5625 5626 5627 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5625 def dimensions @dimensions end |
#metric ⇒ String
The name of the metric to which this override applies. An example name would
be: compute.googleapis.com/cpus
Corresponds to the JSON property metric
5631 5632 5633 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5631 def metric @metric end |
#name ⇒ String
The resource name of the override. This name is generated by the server when
the override is created. Example names would be: projects/123/services/
compute.googleapis.com/consumerQuotaMetrics/compute.googleapis.com%2Fcpus/
limits/%2Fproject%2Fregion/adminOverrides/4a3f2c1d projects/123/services/
compute.googleapis.com/consumerQuotaMetrics/compute.googleapis.com%2Fcpus/
limits/%2Fproject%2Fregion/consumerOverrides/4a3f2c1d The resource name is
intended to be opaque and should not be parsed for its component strings,
since its representation could change in the future.
Corresponds to the JSON property name
5643 5644 5645 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5643 def name @name end |
#override_value ⇒ Fixnum
The overriding quota limit value. Can be any nonnegative integer, or -1 (
unlimited quota).
Corresponds to the JSON property overrideValue
5649 5650 5651 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5649 def override_value @override_value end |
#unit ⇒ String
The limit unit of the limit to which this override applies. An example unit
would be: 1/project/regionNote thatprojectandregionare not
placeholders in this example; the literal charactersand`occur in the
string.
Corresponds to the JSON propertyunit`
5657 5658 5659 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5657 def unit @unit end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5664 5665 5666 5667 5668 5669 5670 5671 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5664 def update!(**args) @admin_override_ancestor = args[:admin_override_ancestor] if args.key?(:admin_override_ancestor) @dimensions = args[:dimensions] if args.key?(:dimensions) @metric = args[:metric] if args.key?(:metric) @name = args[:name] if args.key?(:name) @override_value = args[:override_value] if args.key?(:override_value) @unit = args[:unit] if args.key?(:unit) end |