Class: Google::Apis::ServiceusageV1beta1::Service

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

A service that is available for use by the consumer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Service

Returns a new instance of Service.



5660
5661
5662
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5660

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configGoogle::Apis::ServiceusageV1beta1::ServiceConfig

The configuration of the service. Corresponds to the JSON property config



5642
5643
5644
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5642

def config
  @config
end

#nameString

The resource name of the consumer and service. A valid name would be: - projects/123/services/serviceusage.googleapis.com Corresponds to the JSON property name

Returns:

  • (String)


5648
5649
5650
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5648

def name
  @name
end

#parentString

The resource name of the consumer. A valid name would be: - projects/123 Corresponds to the JSON property parent

Returns:

  • (String)


5653
5654
5655
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5653

def parent
  @parent
end

#stateString

Whether or not the service has been enabled for use by the consumer. Corresponds to the JSON property state

Returns:

  • (String)


5658
5659
5660
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5658

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5665
5666
5667
5668
5669
5670
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5665

def update!(**args)
  @config = args[:config] if args.key?(:config)
  @name = args[:name] if args.key?(:name)
  @parent = args[:parent] if args.key?(:parent)
  @state = args[:state] if args.key?(:state)
end