Class: Google::Apis::ServiceusageV1beta1::ServiceUsageService

Inherits:
Core::BaseService
  • Object
show all
Defined in:
lib/google/apis/serviceusage_v1beta1/service.rb

Overview

Service Usage API

Enables services that service consumers want to use on Google Cloud Platform, lists the available or enabled services, or disables services that service consumers no longer use.

Examples:

require 'google/apis/serviceusage_v1beta1'

Serviceusage = Google::Apis::ServiceusageV1beta1 # Alias the module
service = Serviceusage::ServiceUsageService.new

See Also:

Constant Summary collapse

DEFAULT_ENDPOINT_TEMPLATE =
"https://serviceusage.$UNIVERSE_DOMAIN$/"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeServiceUsageService

Returns a new instance of ServiceUsageService.



49
50
51
52
53
54
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 49

def initialize
  super(DEFAULT_ENDPOINT_TEMPLATE, '',
        client_name: 'google-apis-serviceusage_v1beta1',
        client_version: Google::Apis::ServiceusageV1beta1::GEM_VERSION)
  @batch_path = 'batch'
end

Instance Attribute Details

#keyString

Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.

Returns:

  • (String)

    API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.



42
43
44
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 42

def key
  @key
end

#quota_userString

Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

Returns:

  • (String)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.



47
48
49
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 47

def quota_user
  @quota_user
end

Instance Method Details

#batch_enable_services(parent, batch_enable_services_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceusageV1beta1::Operation

Enables multiple services on a project. The operation is atomic: if enabling any service fails, then the entire batch fails, and no state changes occur. Operation response type: google.protobuf.Empty

Parameters:

  • parent (String)

    Parent to enable services on. An example name would be: projects/123 where 123 is the project number (not project ID). The BatchEnableServices method currently only supports projects.

  • batch_enable_services_request_object (Google::Apis::ServiceusageV1beta1::BatchEnableServicesRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



161
162
163
164
165
166
167
168
169
170
171
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 161

def batch_enable_services(parent, batch_enable_services_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1beta1/{+parent}/services:batchEnable', options)
  command.request_representation = Google::Apis::ServiceusageV1beta1::BatchEnableServicesRequest::Representation
  command.request_object = batch_enable_services_request_object
  command.response_representation = Google::Apis::ServiceusageV1beta1::Operation::Representation
  command.response_class = Google::Apis::ServiceusageV1beta1::Operation
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#create_service_consumer_quota_metric_limit_admin_override(parent, quota_override_object = nil, force: nil, force_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceusageV1beta1::Operation

Creates an admin override. An admin override is applied by an administrator of a parent folder or parent organization of the consumer receiving the override. An admin override is intended to limit the amount of quota the consumer can use out of the total quota pool allocated to all children of the folder or organization.

Parameters:

  • parent (String)

    The resource name of the parent quota limit, returned by a ListConsumerQuotaMetrics or GetConsumerQuotaMetric call. An example name would be: projects/123/services/compute.googleapis.com/consumerQuotaMetrics/compute. googleapis.com%2Fcpus/limits/%2Fproject%2Fregion

  • quota_override_object (Google::Apis::ServiceusageV1beta1::QuotaOverride) (defaults to: nil)
  • force (Boolean) (defaults to: nil)

    Whether to force the creation of the quota override. Setting the force parameter to 'true' ignores all quota safety checks that would fail the request. QuotaSafetyCheck lists all such validations. If force is set to true, it is recommended to include a case id in "X-Goog-Request-Reason" header when sending the request.

  • force_only (Array<String>, String) (defaults to: nil)

    The list of quota safety checks to ignore before the override mutation. Unlike 'force' field that ignores all the quota safety checks, the 'force_only' field ignores only the specified checks; other checks are still enforced. The 'force' and 'force_only' fields cannot both be set. If force_only is specified, it is recommended to include a case id in "X-Goog-Request-Reason" header when sending the request.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



596
597
598
599
600
601
602
603
604
605
606
607
608
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 596

def create_service_consumer_quota_metric_limit_admin_override(parent, quota_override_object = nil, force: nil, force_only: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1beta1/{+parent}/adminOverrides', options)
  command.request_representation = Google::Apis::ServiceusageV1beta1::QuotaOverride::Representation
  command.request_object = quota_override_object
  command.response_representation = Google::Apis::ServiceusageV1beta1::Operation::Representation
  command.response_class = Google::Apis::ServiceusageV1beta1::Operation
  command.params['parent'] = parent unless parent.nil?
  command.query['force'] = force unless force.nil?
  command.query['forceOnly'] = force_only unless force_only.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#create_service_consumer_quota_metric_limit_consumer_override(parent, quota_override_object = nil, force: nil, force_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceusageV1beta1::Operation

Creates a consumer override. A consumer override is applied to the consumer on its own authority to limit its own quota usage. Consumer overrides cannot be used to grant more quota than would be allowed by admin overrides, producer overrides, or the default limit of the service.

Parameters:

  • parent (String)

    The resource name of the parent quota limit, returned by a ListConsumerQuotaMetrics or GetConsumerQuotaMetric call. An example name would be: projects/123/services/compute.googleapis.com/consumerQuotaMetrics/compute. googleapis.com%2Fcpus/limits/%2Fproject%2Fregion

  • quota_override_object (Google::Apis::ServiceusageV1beta1::QuotaOverride) (defaults to: nil)
  • force (Boolean) (defaults to: nil)

    Whether to force the creation of the quota override. Setting the force parameter to 'true' ignores all quota safety checks that would fail the request. QuotaSafetyCheck lists all such validations. If force is set to true, it is recommended to include a case id in "X-Goog-Request-Reason" header when sending the request.

  • force_only (Array<String>, String) (defaults to: nil)

    The list of quota safety checks to ignore before the override mutation. Unlike 'force' field that ignores all the quota safety checks, the 'force_only' field ignores only the specified checks; other checks are still enforced. The 'force' and 'force_only' fields cannot both be set. If force_only is specified, it is recommended to include a case id in "X-Goog-Request-Reason" header when sending the request.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



790
791
792
793
794
795
796
797
798
799
800
801
802
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 790

def create_service_consumer_quota_metric_limit_consumer_override(parent, quota_override_object = nil, force: nil, force_only: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1beta1/{+parent}/consumerOverrides', options)
  command.request_representation = Google::Apis::ServiceusageV1beta1::QuotaOverride::Representation
  command.request_object = quota_override_object
  command.response_representation = Google::Apis::ServiceusageV1beta1::Operation::Representation
  command.response_class = Google::Apis::ServiceusageV1beta1::Operation
  command.params['parent'] = parent unless parent.nil?
  command.query['force'] = force unless force.nil?
  command.query['forceOnly'] = force_only unless force_only.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_service_consumer_quota_metric_limit_admin_override(name, force: nil, force_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceusageV1beta1::Operation

Deletes an admin override.

Parameters:

  • name (String)

    The resource name of the override to delete. An example name would be: projects/123/services/compute.googleapis.com/consumerQuotaMetrics/compute. googleapis.com%2Fcpus/limits/%2Fproject%2Fregion/adminOverrides/4a3f2c1d

  • force (Boolean) (defaults to: nil)

    Whether to force the deletion of the quota override. Setting the force parameter to 'true' ignores all quota safety checks that would fail the request. QuotaSafetyCheck lists all such validations. If force is set to true, it is recommended to include a case id in "X-Goog-Request-Reason" header when sending the request.

  • force_only (Array<String>, String) (defaults to: nil)

    The list of quota safety checks to ignore before the override mutation. Unlike 'force' field that ignores all the quota safety checks, the 'force_only' field ignores only the specified checks; other checks are still enforced. The 'force' and 'force_only' fields cannot both be set. If force_only is specified, it is recommended to include a case id in "X-Goog-Request-Reason" header when sending the request.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



645
646
647
648
649
650
651
652
653
654
655
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 645

def delete_service_consumer_quota_metric_limit_admin_override(name, force: nil, force_only: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:delete, 'v1beta1/{+name}', options)
  command.response_representation = Google::Apis::ServiceusageV1beta1::Operation::Representation
  command.response_class = Google::Apis::ServiceusageV1beta1::Operation
  command.params['name'] = name unless name.nil?
  command.query['force'] = force unless force.nil?
  command.query['forceOnly'] = force_only unless force_only.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_service_consumer_quota_metric_limit_consumer_override(name, force: nil, force_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceusageV1beta1::Operation

Deletes a consumer override.

Parameters:

  • name (String)

    The resource name of the override to delete. An example name would be: projects/123/services/compute.googleapis.com/consumerQuotaMetrics/compute. googleapis.com%2Fcpus/limits/%2Fproject%2Fregion/consumerOverrides/4a3f2c1d

  • force (Boolean) (defaults to: nil)

    Whether to force the deletion of the quota override. Setting the force parameter to 'true' ignores all quota safety checks that would fail the request. QuotaSafetyCheck lists all such validations. If force is set to true, it is recommended to include a case id in "X-Goog-Request-Reason" header when sending the request.

  • force_only (Array<String>, String) (defaults to: nil)

    The list of quota safety checks to ignore before the override mutation. Unlike 'force' field that ignores all the quota safety checks, the 'force_only' field ignores only the specified checks; other checks are still enforced. The 'force' and 'force_only' fields cannot both be set. If force_only is specified, it is recommended to include a case id in "X-Goog-Request-Reason" header when sending the request.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



839
840
841
842
843
844
845
846
847
848
849
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 839

def delete_service_consumer_quota_metric_limit_consumer_override(name, force: nil, force_only: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:delete, 'v1beta1/{+name}', options)
  command.response_representation = Google::Apis::ServiceusageV1beta1::Operation::Representation
  command.response_class = Google::Apis::ServiceusageV1beta1::Operation
  command.params['name'] = name unless name.nil?
  command.query['force'] = force unless force.nil?
  command.query['forceOnly'] = force_only unless force_only.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#disable_service(name, disable_service_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceusageV1beta1::Operation

Disables a service so that it can no longer be used with a project. This prevents unintended usage that may cause unexpected billing charges or security leaks. It is not valid to call the disable method on a service that is not currently enabled. Callers will receive a FAILED_PRECONDITION status if the target service is not currently enabled. Operation response type: google.protobuf.Empty

Parameters:

  • name (String)

    Name of the consumer and service to disable the service on. The enable and disable methods currently only support projects. An example name would be: projects/123/services/serviceusage.googleapis.com where 123 is the project number (not project ID).

  • disable_service_request_object (Google::Apis::ServiceusageV1beta1::DisableServiceRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



202
203
204
205
206
207
208
209
210
211
212
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 202

def disable_service(name, disable_service_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1beta1/{+name}:disable', options)
  command.request_representation = Google::Apis::ServiceusageV1beta1::DisableServiceRequest::Representation
  command.request_object = disable_service_request_object
  command.response_representation = Google::Apis::ServiceusageV1beta1::Operation::Representation
  command.response_class = Google::Apis::ServiceusageV1beta1::Operation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#enable_service(name, enable_service_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceusageV1beta1::Operation

Enables a service so that it can be used with a project. Operation response type: google.protobuf.Empty

Parameters:

  • name (String)

    Name of the consumer and service to enable the service on. The EnableService and DisableService methods currently only support projects. Enabling a service requires that the service is public or is shared with the user enabling the service. An example name would be: projects/123/services/ serviceusage.googleapis.com where 123 is the project number (not project ID) .

  • enable_service_request_object (Google::Apis::ServiceusageV1beta1::EnableServiceRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



241
242
243
244
245
246
247
248
249
250
251
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 241

def enable_service(name, enable_service_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1beta1/{+name}:enable', options)
  command.request_representation = Google::Apis::ServiceusageV1beta1::EnableServiceRequest::Representation
  command.request_object = enable_service_request_object
  command.response_representation = Google::Apis::ServiceusageV1beta1::Operation::Representation
  command.response_class = Google::Apis::ServiceusageV1beta1::Operation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#generate_service_service_identity(parent, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceusageV1beta1::Operation

Generates service identity for service.

Parameters:

  • parent (String)

    Name of the consumer and service to generate an identity for. The GenerateServiceIdentity methods currently support projects, folders, organizations. Example parents would be: projects/123/services/example. googleapis.com folders/123/services/example.googleapis.com organizations/ 123/services/example.googleapis.com

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



277
278
279
280
281
282
283
284
285
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 277

def generate_service_service_identity(parent, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1beta1/{+parent}:generateServiceIdentity', options)
  command.response_representation = Google::Apis::ServiceusageV1beta1::Operation::Representation
  command.response_class = Google::Apis::ServiceusageV1beta1::Operation
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceusageV1beta1::Operation

Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.

Parameters:

  • name (String)

    The name of the operation resource.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



77
78
79
80
81
82
83
84
85
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 77

def get_operation(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta1/{+name}', options)
  command.response_representation = Google::Apis::ServiceusageV1beta1::Operation::Representation
  command.response_class = Google::Apis::ServiceusageV1beta1::Operation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceusageV1beta1::Service

Returns the service configuration and enabled state for a given service.

Parameters:

  • name (String)

    Name of the consumer and service to get the ConsumerState for. An example name would be: projects/123/services/serviceusage.googleapis.com where 123 is the project number (not project ID).

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



309
310
311
312
313
314
315
316
317
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 309

def get_service(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta1/{+name}', options)
  command.response_representation = Google::Apis::ServiceusageV1beta1::Service::Representation
  command.response_class = Google::Apis::ServiceusageV1beta1::Service
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_service_consumer_quota_metric(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceusageV1beta1::ConsumerQuotaMetric

Retrieves a summary of quota information for a specific quota metric

Parameters:

  • name (String)

    The resource name of the quota. An example name would be: projects/123/ services/serviceusage.googleapis.com/consumerQuotaMetrics/serviceusage. googleapis.com%2Fmutate_requests

  • view (String) (defaults to: nil)

    Specifies the level of detail for quota information in the response.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



391
392
393
394
395
396
397
398
399
400
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 391

def get_service_consumer_quota_metric(name, view: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta1/{+name}', options)
  command.response_representation = Google::Apis::ServiceusageV1beta1::ConsumerQuotaMetric::Representation
  command.response_class = Google::Apis::ServiceusageV1beta1::ConsumerQuotaMetric
  command.params['name'] = name unless name.nil?
  command.query['view'] = view unless view.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_service_consumer_quota_metric_limit(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceusageV1beta1::ConsumerQuotaLimit

Retrieves a summary of quota information for a specific quota limit.

Parameters:

  • name (String)

    The resource name of the quota limit. Use the quota limit resource name returned by previous ListConsumerQuotaMetrics and GetConsumerQuotaMetric API calls.

  • view (String) (defaults to: nil)

    Specifies the level of detail for quota information in the response.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



544
545
546
547
548
549
550
551
552
553
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 544

def get_service_consumer_quota_metric_limit(name, view: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta1/{+name}', options)
  command.response_representation = Google::Apis::ServiceusageV1beta1::ConsumerQuotaLimit::Representation
  command.response_class = Google::Apis::ServiceusageV1beta1::ConsumerQuotaLimit
  command.params['name'] = name unless name.nil?
  command.query['view'] = view unless view.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#import_consumer_quota_metric_admin_overrides(parent, import_admin_overrides_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceusageV1beta1::Operation

Creates or updates multiple admin overrides atomically, all on the same consumer, but on many different metrics or limits. The name field in the quota override message should not be set.

Parameters:

  • parent (String)

    The resource name of the consumer. An example name would be: projects/123/ services/compute.googleapis.com

  • import_admin_overrides_request_object (Google::Apis::ServiceusageV1beta1::ImportAdminOverridesRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



426
427
428
429
430
431
432
433
434
435
436
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 426

def import_consumer_quota_metric_admin_overrides(parent, import_admin_overrides_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1beta1/{+parent}/consumerQuotaMetrics:importAdminOverrides', options)
  command.request_representation = Google::Apis::ServiceusageV1beta1::ImportAdminOverridesRequest::Representation
  command.request_object = import_admin_overrides_request_object
  command.response_representation = Google::Apis::ServiceusageV1beta1::Operation::Representation
  command.response_class = Google::Apis::ServiceusageV1beta1::Operation
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#import_consumer_quota_metric_consumer_overrides(parent, import_consumer_overrides_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceusageV1beta1::Operation

Creates or updates multiple consumer overrides atomically, all on the same consumer, but on many different metrics or limits. The name field in the quota override message should not be set.

Parameters:

  • parent (String)

    The resource name of the consumer. An example name would be: projects/123/ services/compute.googleapis.com

  • import_consumer_overrides_request_object (Google::Apis::ServiceusageV1beta1::ImportConsumerOverridesRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



462
463
464
465
466
467
468
469
470
471
472
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 462

def import_consumer_quota_metric_consumer_overrides(parent, import_consumer_overrides_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1beta1/{+parent}/consumerQuotaMetrics:importConsumerOverrides', options)
  command.request_representation = Google::Apis::ServiceusageV1beta1::ImportConsumerOverridesRequest::Representation
  command.request_object = import_consumer_overrides_request_object
  command.response_representation = Google::Apis::ServiceusageV1beta1::Operation::Representation
  command.response_class = Google::Apis::ServiceusageV1beta1::Operation
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_operations(filter: nil, name: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceusageV1beta1::ListOperationsResponse

Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns UNIMPLEMENTED.

Parameters:

  • filter (String) (defaults to: nil)

    The standard list filter.

  • name (String) (defaults to: nil)

    The name of the operation's parent resource.

  • page_size (Fixnum) (defaults to: nil)

    The standard list page size.

  • page_token (String) (defaults to: nil)

    The standard list page token.

  • return_partial_success (Boolean) (defaults to: nil)

    When set to true, operations that are reachable are returned as normal, and those that are unreachable are returned in the ListOperationsResponse. unreachable field. This can only be true when reading across collections. For example, when parent is set to "projects/example/locations/-". This field is not supported by default and will result in an UNIMPLEMENTED error if set unless explicitly documented otherwise in service or product specific documentation.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 122

def list_operations(filter: nil, name: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta1/operations', options)
  command.response_representation = Google::Apis::ServiceusageV1beta1::ListOperationsResponse::Representation
  command.response_class = Google::Apis::ServiceusageV1beta1::ListOperationsResponse
  command.query['filter'] = filter unless filter.nil?
  command.query['name'] = name unless name.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_service_consumer_quota_metric_limit_admin_overrides(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceusageV1beta1::ListAdminOverridesResponse

Lists all admin overrides on this limit.

Parameters:

  • parent (String)

    The resource name of the parent quota limit, returned by a ListConsumerQuotaMetrics or GetConsumerQuotaMetric call. An example name would be: projects/123/services/compute.googleapis.com/consumerQuotaMetrics/compute. googleapis.com%2Fcpus/limits/%2Fproject%2Fregion

  • page_size (Fixnum) (defaults to: nil)

    Requested size of the next page of data.

  • page_token (String) (defaults to: nil)

    Token identifying which result to start with; returned by a previous list call.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



684
685
686
687
688
689
690
691
692
693
694
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 684

def list_service_consumer_quota_metric_limit_admin_overrides(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta1/{+parent}/adminOverrides', options)
  command.response_representation = Google::Apis::ServiceusageV1beta1::ListAdminOverridesResponse::Representation
  command.response_class = Google::Apis::ServiceusageV1beta1::ListAdminOverridesResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_service_consumer_quota_metric_limit_consumer_overrides(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceusageV1beta1::ListConsumerOverridesResponse

Lists all consumer overrides on this limit.

Parameters:

  • parent (String)

    The resource name of the parent quota limit, returned by a ListConsumerQuotaMetrics or GetConsumerQuotaMetric call. An example name would be: projects/123/services/compute.googleapis.com/consumerQuotaMetrics/compute. googleapis.com%2Fcpus/limits/%2Fproject%2Fregion

  • page_size (Fixnum) (defaults to: nil)

    Requested size of the next page of data.

  • page_token (String) (defaults to: nil)

    Token identifying which result to start with; returned by a previous list call.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



878
879
880
881
882
883
884
885
886
887
888
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 878

def list_service_consumer_quota_metric_limit_consumer_overrides(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta1/{+parent}/consumerOverrides', options)
  command.response_representation = Google::Apis::ServiceusageV1beta1::ListConsumerOverridesResponse::Representation
  command.response_class = Google::Apis::ServiceusageV1beta1::ListConsumerOverridesResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_service_consumer_quota_metrics(parent, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceusageV1beta1::ListConsumerQuotaMetricsResponse

Retrieves a summary of all quota information visible to the service consumer, organized by service metric. Each metric includes information about all of its defined limits. Each limit includes the limit configuration (quota unit, preciseness, default value), the current effective limit value, and all of the overrides applied to the limit.

Parameters:

  • parent (String)

    Parent of the quotas resource. Some example names would be: projects/123/ services/serviceconsumermanagement.googleapis.com folders/345/services/ serviceconsumermanagement.googleapis.com organizations/456/services/ serviceconsumermanagement.googleapis.com

  • page_size (Fixnum) (defaults to: nil)

    Requested size of the next page of data.

  • page_token (String) (defaults to: nil)

    Token identifying which result to start with; returned by a previous list call.

  • view (String) (defaults to: nil)

    Specifies the level of detail for quota information in the response.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



507
508
509
510
511
512
513
514
515
516
517
518
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 507

def list_service_consumer_quota_metrics(parent, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta1/{+parent}/consumerQuotaMetrics', options)
  command.response_representation = Google::Apis::ServiceusageV1beta1::ListConsumerQuotaMetricsResponse::Representation
  command.response_class = Google::Apis::ServiceusageV1beta1::ListConsumerQuotaMetricsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['view'] = view unless view.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_services(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceusageV1beta1::ListServicesResponse

Lists all services available to the specified project, and the current state of those services with respect to the project. The list includes all public services, all services for which the calling user has the servicemanagement. services.bind permission, and all services that have already been enabled on the project. The list can be filtered to only include services in a specific state, for example to only include services enabled on the project.

Parameters:

  • parent (String)

    Parent to search for services on. An example name would be: projects/123 where 123 is the project number (not project ID).

  • filter (String) (defaults to: nil)

    Only list services that conform to the given filter. The allowed filter strings are state:ENABLED and state:DISABLED.

  • page_size (Fixnum) (defaults to: nil)

    Requested size of the next page of data. Requested page size cannot exceed 200. If not set, the default page size is 50.

  • page_token (String) (defaults to: nil)

    Token identifying which result to start with, which is returned by a previous list call.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 354

def list_services(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1beta1/{+parent}/services', options)
  command.response_representation = Google::Apis::ServiceusageV1beta1::ListServicesResponse::Representation
  command.response_class = Google::Apis::ServiceusageV1beta1::ListServicesResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#patch_service_consumer_quota_metric_limit_admin_override(name, quota_override_object = nil, force: nil, force_only: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceusageV1beta1::Operation

Updates an admin override.

Parameters:

  • name (String)

    The resource name of the override to update. An example name would be: projects/123/services/compute.googleapis.com/consumerQuotaMetrics/compute. googleapis.com%2Fcpus/limits/%2Fproject%2Fregion/adminOverrides/4a3f2c1d

  • quota_override_object (Google::Apis::ServiceusageV1beta1::QuotaOverride) (defaults to: nil)
  • force (Boolean) (defaults to: nil)

    Whether to force the update of the quota override. Setting the force parameter to 'true' ignores all quota safety checks that would fail the request. QuotaSafetyCheck lists all such validations. If force is set to true, it is recommended to include a case id in "X-Goog-Request-Reason" header when sending the request.

  • force_only (Array<String>, String) (defaults to: nil)

    The list of quota safety checks to ignore before the override mutation. Unlike 'force' field that ignores all the quota safety checks, the 'force_only' field ignores only the specified checks; other checks are still enforced. The 'force' and 'force_only' fields cannot both be set. If force_only is specified, it is recommended to include a case id in "X-Goog-Request-Reason" header when sending the request.

  • update_mask (String) (defaults to: nil)

    Update only the specified fields of the override. If unset, all fields will be updated.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



735
736
737
738
739
740
741
742
743
744
745
746
747
748
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 735

def patch_service_consumer_quota_metric_limit_admin_override(name, quota_override_object = nil, force: nil, force_only: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:patch, 'v1beta1/{+name}', options)
  command.request_representation = Google::Apis::ServiceusageV1beta1::QuotaOverride::Representation
  command.request_object = quota_override_object
  command.response_representation = Google::Apis::ServiceusageV1beta1::Operation::Representation
  command.response_class = Google::Apis::ServiceusageV1beta1::Operation
  command.params['name'] = name unless name.nil?
  command.query['force'] = force unless force.nil?
  command.query['forceOnly'] = force_only unless force_only.nil?
  command.query['updateMask'] = update_mask unless update_mask.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#patch_service_consumer_quota_metric_limit_consumer_override(name, quota_override_object = nil, force: nil, force_only: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceusageV1beta1::Operation

Updates a consumer override.

Parameters:

  • name (String)

    The resource name of the override to update. An example name would be: projects/123/services/compute.googleapis.com/consumerQuotaMetrics/compute. googleapis.com%2Fcpus/limits/%2Fproject%2Fregion/consumerOverrides/4a3f2c1d

  • quota_override_object (Google::Apis::ServiceusageV1beta1::QuotaOverride) (defaults to: nil)
  • force (Boolean) (defaults to: nil)

    Whether to force the update of the quota override. Setting the force parameter to 'true' ignores all quota safety checks that would fail the request. QuotaSafetyCheck lists all such validations. If force is set to true, it is recommended to include a case id in "X-Goog-Request-Reason" header when sending the request.

  • force_only (Array<String>, String) (defaults to: nil)

    The list of quota safety checks to ignore before the override mutation. Unlike 'force' field that ignores all the quota safety checks, the 'force_only' field ignores only the specified checks; other checks are still enforced. The 'force' and 'force_only' fields cannot both be set. If force_only is specified, it is recommended to include a case id in "X-Goog-Request-Reason" header when sending the request.

  • update_mask (String) (defaults to: nil)

    Update only the specified fields of the override. If unset, all fields will be updated.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



929
930
931
932
933
934
935
936
937
938
939
940
941
942
# File 'lib/google/apis/serviceusage_v1beta1/service.rb', line 929

def patch_service_consumer_quota_metric_limit_consumer_override(name, quota_override_object = nil, force: nil, force_only: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:patch, 'v1beta1/{+name}', options)
  command.request_representation = Google::Apis::ServiceusageV1beta1::QuotaOverride::Representation
  command.request_object = quota_override_object
  command.response_representation = Google::Apis::ServiceusageV1beta1::Operation::Representation
  command.response_class = Google::Apis::ServiceusageV1beta1::Operation
  command.params['name'] = name unless name.nil?
  command.query['force'] = force unless force.nil?
  command.query['forceOnly'] = force_only unless force_only.nil?
  command.query['updateMask'] = update_mask unless update_mask.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end