Class: Google::Apis::ServiceusageV1beta1::SystemParameters
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::SystemParameters
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
System parameter configuration A system parameter is a special kind of
parameter defined by the API system, not by an individual API. It is typically mapped to an HTTP header and/or a URL query parameter. This configuration specifies which methods change the names of the system parameters.
Instance Attribute Summary collapse
-
#rules ⇒ Array<Google::Apis::ServiceusageV1beta1::SystemParameterRule>
Define system parameters.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SystemParameters
constructor
A new instance of SystemParameters.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SystemParameters
Returns a new instance of SystemParameters.
6011 6012 6013 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6011 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rules ⇒ Array<Google::Apis::ServiceusageV1beta1::SystemParameterRule>
Define system parameters. The parameters defined here will override the
default parameters implemented by the system. If this field is missing from
the service config, default system parameters will be used. Default system
parameters and names is implementation-dependent. Example: define api key for
all methods system_parameters rules: - selector: "" parameters: - name:
api_key url_query_parameter: api_key Example: define 2 api key names for a
specific method. system_parameters rules: - selector: "/ListShelves"
parameters: - name: api_key http_header: Api-Key1 - name: api_key http_header:
Api-Key2 **NOTE:* All service configuration rules follow "last one wins"
order.
Corresponds to the JSON property rules
6009 6010 6011 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6009 def rules @rules end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6016 6017 6018 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6016 def update!(**args) @rules = args[:rules] if args.key?(:rules) end |