Class: Google::Apis::ServiceusageV1beta1::ConsumerPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::ConsumerPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
Consumer Policy is a set of rules that define what services or service groups can be used for a cloud resource hierarchy.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#enable_rules ⇒ Array<Google::Apis::ServiceusageV1beta1::EnableRule>
Enable rules define usable services and service groups.
-
#etag ⇒ String
An opaque tag indicating the current version of the policy, used for concurrency control.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
The last-modified time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConsumerPolicy
constructor
A new instance of ConsumerPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConsumerPolicy
Returns a new instance of ConsumerPolicy.
1145 1146 1147 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1145 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Annotations is an unstructured key-value map stored with a policy
that may be set by external tools to store and retrieve arbitrary metadata.
They are not queryable and should be preserved when modifying objects. AIP-
128
Corresponds to the JSON property annotations
1119 1120 1121 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1119 def annotations @annotations end |
#enable_rules ⇒ Array<Google::Apis::ServiceusageV1beta1::EnableRule>
Enable rules define usable services and service groups.
Corresponds to the JSON property enableRules
1124 1125 1126 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1124 def enable_rules @enable_rules end |
#etag ⇒ String
An opaque tag indicating the current version of the policy, used for
concurrency control.
Corresponds to the JSON property etag
1130 1131 1132 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1130 def etag @etag end |
#name ⇒ String
Output only. The resource name of the policy. We only allow consumer policy
name as default for now: projects/12345/consumerPolicies/default, folders/
12345/consumerPolicies/default, organizations/12345/consumerPolicies/default
.
Corresponds to the JSON property name
1138 1139 1140 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1138 def name @name end |
#update_time ⇒ String
The last-modified time.
Corresponds to the JSON property updateTime
1143 1144 1145 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1143 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1150 1151 1152 1153 1154 1155 1156 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1150 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @enable_rules = args[:enable_rules] if args.key?(:enable_rules) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |