Class: Google::Apis::ServiceusageV1beta1::ConsumerPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::ConsumerPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
Consumer Policy is a set of rules that define what services or service groups can be used for a cloud resource hierarchy.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#enable_rules ⇒ Array<Google::Apis::ServiceusageV1beta1::EnableRule>
Enable rules define usable services and service groups.
-
#etag ⇒ String
An opaque tag indicating the current version of the policy, used for concurrency control.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
The last-modified time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConsumerPolicy
constructor
A new instance of ConsumerPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConsumerPolicy
Returns a new instance of ConsumerPolicy.
1142 1143 1144 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1142 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Annotations is an unstructured key-value map stored with a policy
that may be set by external tools to store and retrieve arbitrary metadata.
They are not queryable and should be preserved when modifying objects. AIP-
128
Corresponds to the JSON property annotations
1116 1117 1118 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1116 def annotations @annotations end |
#enable_rules ⇒ Array<Google::Apis::ServiceusageV1beta1::EnableRule>
Enable rules define usable services and service groups.
Corresponds to the JSON property enableRules
1121 1122 1123 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1121 def enable_rules @enable_rules end |
#etag ⇒ String
An opaque tag indicating the current version of the policy, used for
concurrency control.
Corresponds to the JSON property etag
1127 1128 1129 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1127 def etag @etag end |
#name ⇒ String
Output only. The resource name of the policy. We only allow consumer policy
name as default for now: projects/12345/consumerPolicies/default, folders/
12345/consumerPolicies/default, organizations/12345/consumerPolicies/default
.
Corresponds to the JSON property name
1135 1136 1137 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1135 def name @name end |
#update_time ⇒ String
The last-modified time.
Corresponds to the JSON property updateTime
1140 1141 1142 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1140 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1147 1148 1149 1150 1151 1152 1153 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1147 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @enable_rules = args[:enable_rules] if args.key?(:enable_rules) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |