Class: Google::Apis::ServiceusageV1beta1::ConsumerQuotaLimit
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::ConsumerQuotaLimit
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
Consumer quota settings for a quota limit.
Instance Attribute Summary collapse
-
#allows_admin_overrides ⇒ Boolean
(also: #allows_admin_overrides?)
Whether admin overrides are allowed on this limit Corresponds to the JSON property
allowsAdminOverrides. -
#is_precise ⇒ Boolean
(also: #is_precise?)
Whether this limit is precise or imprecise.
-
#metric ⇒ String
The name of the parent metric of this limit.
-
#name ⇒ String
The resource name of the quota limit.
-
#quota_buckets ⇒ Array<Google::Apis::ServiceusageV1beta1::QuotaBucket>
Summary of the enforced quota buckets, organized by quota dimension, ordered from least specific to most specific (for example, the global default bucket, with no quota dimensions, will always appear first).
-
#supported_locations ⇒ Array<String>
List of all supported locations.
-
#unit ⇒ String
The limit unit.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConsumerQuotaLimit
constructor
A new instance of ConsumerQuotaLimit.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConsumerQuotaLimit
Returns a new instance of ConsumerQuotaLimit.
1210 1211 1212 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1210 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allows_admin_overrides ⇒ Boolean Also known as: allows_admin_overrides?
Whether admin overrides are allowed on this limit
Corresponds to the JSON property allowsAdminOverrides
1166 1167 1168 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1166 def allows_admin_overrides @allows_admin_overrides end |
#is_precise ⇒ Boolean Also known as: is_precise?
Whether this limit is precise or imprecise.
Corresponds to the JSON property isPrecise
1172 1173 1174 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1172 def is_precise @is_precise end |
#metric ⇒ String
The name of the parent metric of this limit. An example name would be:
compute.googleapis.com/cpus
Corresponds to the JSON property metric
1179 1180 1181 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1179 def metric @metric end |
#name ⇒ String
The resource name of the quota limit. An example name would be: projects/123/
services/compute.googleapis.com/consumerQuotaMetrics/compute.googleapis.com%
2Fcpus/limits/%2Fproject%2Fregion The resource name is intended to be opaque
and should not be parsed for its component strings, since its representation
could change in the future.
Corresponds to the JSON property name
1188 1189 1190 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1188 def name @name end |
#quota_buckets ⇒ Array<Google::Apis::ServiceusageV1beta1::QuotaBucket>
Summary of the enforced quota buckets, organized by quota dimension, ordered
from least specific to most specific (for example, the global default bucket,
with no quota dimensions, will always appear first).
Corresponds to the JSON property quotaBuckets
1195 1196 1197 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1195 def quota_buckets @quota_buckets end |
#supported_locations ⇒ Array<String>
List of all supported locations. This field is present only if the limit has a
region or zone dimension.
Corresponds to the JSON property supportedLocations
1201 1202 1203 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1201 def supported_locations @supported_locations end |
#unit ⇒ String
The limit unit. An example unit would be 1/project/regionNote that
projectandregionare not placeholders in this example; the literal
charactersand`occur in the string.
Corresponds to the JSON propertyunit`
1208 1209 1210 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1208 def unit @unit end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1215 def update!(**args) @allows_admin_overrides = args[:allows_admin_overrides] if args.key?(:allows_admin_overrides) @is_precise = args[:is_precise] if args.key?(:is_precise) @metric = args[:metric] if args.key?(:metric) @name = args[:name] if args.key?(:name) @quota_buckets = args[:quota_buckets] if args.key?(:quota_buckets) @supported_locations = args[:supported_locations] if args.key?(:supported_locations) @unit = args[:unit] if args.key?(:unit) end |