Class: Google::Apis::ServiceusageV1beta1::ContentSecurity
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::ContentSecurity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
ContentSecurity defines the content security related fields of a MCP policy.
Instance Attribute Summary collapse
-
#content_security_providers ⇒ Array<Google::Apis::ServiceusageV1beta1::ContentSecurityProvider>
List of content security providers that are enabled for content scanning.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContentSecurity
constructor
A new instance of ContentSecurity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContentSecurity
Returns a new instance of ContentSecurity.
1289 1290 1291 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1289 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_security_providers ⇒ Array<Google::Apis::ServiceusageV1beta1::ContentSecurityProvider>
List of content security providers that are enabled for content scanning.
Corresponds to the JSON property contentSecurityProviders
1287 1288 1289 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1287 def content_security_providers @content_security_providers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1294 1295 1296 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1294 def update!(**args) @content_security_providers = args[:content_security_providers] if args.key?(:content_security_providers) end |