Class: Google::Apis::ServiceusageV1beta1::CustomErrorRule
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::CustomErrorRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
A custom error rule.
Instance Attribute Summary collapse
-
#is_error_type ⇒ Boolean
(also: #is_error_type?)
Mark this message as possible payload in error response.
-
#selector ⇒ String
Selects messages to which this rule applies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomErrorRule
constructor
A new instance of CustomErrorRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomErrorRule
Returns a new instance of CustomErrorRule.
1544 1545 1546 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1544 def initialize(**args) update!(**args) end |
Instance Attribute Details
#is_error_type ⇒ Boolean Also known as: is_error_type?
Mark this message as possible payload in error response. Otherwise, objects of
this type will be filtered when they appear in error payload.
Corresponds to the JSON property isErrorType
1535 1536 1537 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1535 def is_error_type @is_error_type end |
#selector ⇒ String
Selects messages to which this rule applies. Refer to selector for syntax
details.
Corresponds to the JSON property selector
1542 1543 1544 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1542 def selector @selector end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1549 1550 1551 1552 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1549 def update!(**args) @is_error_type = args[:is_error_type] if args.key?(:is_error_type) @selector = args[:selector] if args.key?(:selector) end |