Class: Google::Apis::ServiceusageV1beta1::CustomErrorRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

A custom error rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomErrorRule

Returns a new instance of CustomErrorRule.



1541
1542
1543
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1541

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#is_error_typeBoolean Also known as: is_error_type?

Mark this message as possible payload in error response. Otherwise, objects of this type will be filtered when they appear in error payload. Corresponds to the JSON property isErrorType

Returns:

  • (Boolean)


1532
1533
1534
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1532

def is_error_type
  @is_error_type
end

#selectorString

Selects messages to which this rule applies. Refer to selector for syntax details. Corresponds to the JSON property selector

Returns:

  • (String)


1539
1540
1541
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1539

def selector
  @selector
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1546
1547
1548
1549
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1546

def update!(**args)
  @is_error_type = args[:is_error_type] if args.key?(:is_error_type)
  @selector = args[:selector] if args.key?(:selector)
end