Class: Google::Apis::ServiceusageV1beta1::DotnetSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

Settings for Dotnet client libraries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DotnetSettings

Returns a new instance of DotnetSettings.



1815
1816
1817
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1815

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commonGoogle::Apis::ServiceusageV1beta1::CommonLanguageSettings

Required information for every language. Corresponds to the JSON property common



1777
1778
1779
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1777

def common
  @common
end

#forced_namespace_aliasesArray<String>

Namespaces which must be aliased in snippets due to a known (but non-generator- predictable) naming collision Corresponds to the JSON property forcedNamespaceAliases

Returns:

  • (Array<String>)


1783
1784
1785
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1783

def forced_namespace_aliases
  @forced_namespace_aliases
end

#handwritten_signaturesArray<String>

Method signatures (in the form "service.method(signature)") which are provided separately, so shouldn't be generated. Snippets calling these methods are still generated, however. Corresponds to the JSON property handwrittenSignatures

Returns:

  • (Array<String>)


1790
1791
1792
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1790

def handwritten_signatures
  @handwritten_signatures
end

#ignored_resourcesArray<String>

List of full resource types to ignore during generation. This is typically used for API-specific Location resources, which should be handled by the generator as if they were actually the common Location resources. Example entry: "documentai.googleapis.com/Location" Corresponds to the JSON property ignoredResources

Returns:

  • (Array<String>)


1798
1799
1800
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1798

def ignored_resources
  @ignored_resources
end

#renamed_resourcesHash<String,String>

Map from full resource types to the effective short name for the resource. This is used when otherwise resource named from different services would cause naming collisions. Example entry: "datalabeling.googleapis.com/Dataset": " DataLabelingDataset" Corresponds to the JSON property renamedResources

Returns:

  • (Hash<String,String>)


1806
1807
1808
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1806

def renamed_resources
  @renamed_resources
end

#renamed_servicesHash<String,String>

Map from original service names to renamed versions. This is used when the default generated types would cause a naming conflict. (Neither name is fully- qualified.) Example: Subscriber to SubscriberServiceApi. Corresponds to the JSON property renamedServices

Returns:

  • (Hash<String,String>)


1813
1814
1815
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1813

def renamed_services
  @renamed_services
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1820
1821
1822
1823
1824
1825
1826
1827
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 1820

def update!(**args)
  @common = args[:common] if args.key?(:common)
  @forced_namespace_aliases = args[:forced_namespace_aliases] if args.key?(:forced_namespace_aliases)
  @handwritten_signatures = args[:handwritten_signatures] if args.key?(:handwritten_signatures)
  @ignored_resources = args[:ignored_resources] if args.key?(:ignored_resources)
  @renamed_resources = args[:renamed_resources] if args.key?(:renamed_resources)
  @renamed_services = args[:renamed_services] if args.key?(:renamed_services)
end