Class: Google::Apis::ServiceusageV1beta1::EnumValue
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::EnumValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
Enum value definition. New usages of this message as an alternative to EnumValueDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#name ⇒ String
Enum value name.
-
#number ⇒ Fixnum
Enum value number.
-
#options ⇒ Array<Google::Apis::ServiceusageV1beta1::Option>
Protocol buffer options.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EnumValue
constructor
A new instance of EnumValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EnumValue
Returns a new instance of EnumValue.
2085 2086 2087 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2085 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Enum value name.
Corresponds to the JSON property name
2073 2074 2075 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2073 def name @name end |
#number ⇒ Fixnum
Enum value number.
Corresponds to the JSON property number
2078 2079 2080 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2078 def number @number end |
#options ⇒ Array<Google::Apis::ServiceusageV1beta1::Option>
Protocol buffer options.
Corresponds to the JSON property options
2083 2084 2085 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2083 def @options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2090 2091 2092 2093 2094 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2090 def update!(**args) @name = args[:name] if args.key?(:name) @number = args[:number] if args.key?(:number) @options = args[:options] if args.key?(:options) end |