Class: Google::Apis::ServiceusageV1beta1::EnumValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

Enum value definition. New usages of this message as an alternative to EnumValueDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EnumValue

Returns a new instance of EnumValue.



2082
2083
2084
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2082

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Enum value name. Corresponds to the JSON property name

Returns:

  • (String)


2070
2071
2072
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2070

def name
  @name
end

#numberFixnum

Enum value number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


2075
2076
2077
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2075

def number
  @number
end

#optionsArray<Google::Apis::ServiceusageV1beta1::Option>

Protocol buffer options. Corresponds to the JSON property options



2080
2081
2082
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2080

def options
  @options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2087
2088
2089
2090
2091
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2087

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @number = args[:number] if args.key?(:number)
  @options = args[:options] if args.key?(:options)
end