Class: Google::Apis::ServiceusageV1beta1::ExperimentalFeatures

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

Experimental features to be included during client library generation. These fields will be deprecated once the feature graduates and is enabled by default.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExperimentalFeatures

Returns a new instance of ExperimentalFeatures.



2125
2126
2127
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2125

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#protobuf_pythonic_types_enabledBoolean Also known as: protobuf_pythonic_types_enabled?

Enables generation of protobuf code using new types that are more Pythonic which are included in protobuf>=5.29.x. This feature will be enabled by default 1 month after launching the feature in preview packages. Corresponds to the JSON property protobufPythonicTypesEnabled

Returns:

  • (Boolean)


2104
2105
2106
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2104

def protobuf_pythonic_types_enabled
  @protobuf_pythonic_types_enabled
end

#rest_async_io_enabledBoolean Also known as: rest_async_io_enabled?

Enables generation of asynchronous REST clients if rest transport is enabled. By default, asynchronous REST clients will not be generated. This feature will be enabled by default 1 month after launching the feature in preview packages. Corresponds to the JSON property restAsyncIoEnabled

Returns:

  • (Boolean)


2113
2114
2115
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2113

def rest_async_io_enabled
  @rest_async_io_enabled
end

#unversioned_package_disabledBoolean Also known as: unversioned_package_disabled?

Disables generation of an unversioned Python package for this client library. This means that the module names will need to be versioned in import statements. For example import google.cloud.library_v2 instead of import google.cloud.library. Corresponds to the JSON property unversionedPackageDisabled

Returns:

  • (Boolean)


2122
2123
2124
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2122

def unversioned_package_disabled
  @unversioned_package_disabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2130
2131
2132
2133
2134
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2130

def update!(**args)
  @protobuf_pythonic_types_enabled = args[:protobuf_pythonic_types_enabled] if args.key?(:protobuf_pythonic_types_enabled)
  @rest_async_io_enabled = args[:rest_async_io_enabled] if args.key?(:rest_async_io_enabled)
  @unversioned_package_disabled = args[:unversioned_package_disabled] if args.key?(:unversioned_package_disabled)
end