Class: Google::Apis::ServiceusageV1beta1::Field

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

A single field of a message type. New usages of this message as an alternative to FieldDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Field

Returns a new instance of Field.



2198
2199
2200
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2198

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cardinalityString

The field cardinality. Corresponds to the JSON property cardinality

Returns:

  • (String)


2148
2149
2150
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2148

def cardinality
  @cardinality
end

#default_valueString

The string value of the default value of this field. Proto2 syntax only. Corresponds to the JSON property defaultValue

Returns:

  • (String)


2153
2154
2155
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2153

def default_value
  @default_value
end

#json_nameString

The field JSON name. Corresponds to the JSON property jsonName

Returns:

  • (String)


2158
2159
2160
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2158

def json_name
  @json_name
end

#kindString

The field type. Corresponds to the JSON property kind

Returns:

  • (String)


2163
2164
2165
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2163

def kind
  @kind
end

#nameString

The field name. Corresponds to the JSON property name

Returns:

  • (String)


2168
2169
2170
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2168

def name
  @name
end

#numberFixnum

The field number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


2173
2174
2175
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2173

def number
  @number
end

#oneof_indexFixnum

The index of the field type in Type.oneofs, for message or enumeration types. The first type has index 1; zero means the type is not in the list. Corresponds to the JSON property oneofIndex

Returns:

  • (Fixnum)


2179
2180
2181
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2179

def oneof_index
  @oneof_index
end

#optionsArray<Google::Apis::ServiceusageV1beta1::Option>

The protocol buffer options. Corresponds to the JSON property options



2184
2185
2186
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2184

def options
  @options
end

#packedBoolean Also known as: packed?

Whether to use alternative packed wire representation. Corresponds to the JSON property packed

Returns:

  • (Boolean)


2189
2190
2191
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2189

def packed
  @packed
end

#type_urlString

The field type URL, without the scheme, for message or enumeration types. Example: "type.googleapis.com/google.protobuf.Timestamp". Corresponds to the JSON property typeUrl

Returns:

  • (String)


2196
2197
2198
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2196

def type_url
  @type_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2203

def update!(**args)
  @cardinality = args[:cardinality] if args.key?(:cardinality)
  @default_value = args[:default_value] if args.key?(:default_value)
  @json_name = args[:json_name] if args.key?(:json_name)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @number = args[:number] if args.key?(:number)
  @oneof_index = args[:oneof_index] if args.key?(:oneof_index)
  @options = args[:options] if args.key?(:options)
  @packed = args[:packed] if args.key?(:packed)
  @type_url = args[:type_url] if args.key?(:type_url)
end