Class: Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2alphaAnalyzeConsumerPolicyResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

The response of analyzing a consumer policy update.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleApiServiceusageV2alphaAnalyzeConsumerPolicyResponse

Returns a new instance of GoogleApiServiceusageV2alphaAnalyzeConsumerPolicyResponse.



3012
3013
3014
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3012

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysisArray<Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2alphaAnalysis>

The list of analyses returned from performing the intended policy update analysis. The analysis is grouped by service name and different analysis types. The empty analysis list means that the consumer policy can be updated without any warnings or blockers. Corresponds to the JSON property analysis



3010
3011
3012
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3010

def analysis
  @analysis
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3017
3018
3019
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3017

def update!(**args)
  @analysis = args[:analysis] if args.key?(:analysis)
end