Class: Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2alphaConsumerPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2alphaConsumerPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
Consumer Policy is a set of rules that define what services or service groups can be used for a cloud resource hierarchy.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#enable_rules ⇒ Array<Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2alphaEnableRule>
Enable rules define usable services, groups, and categories.
-
#etag ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleApiServiceusageV2alphaConsumerPolicy
constructor
A new instance of GoogleApiServiceusageV2alphaConsumerPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleApiServiceusageV2alphaConsumerPolicy
Returns a new instance of GoogleApiServiceusageV2alphaConsumerPolicy.
2979 2980 2981 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2979 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Annotations is an unstructured key-value map stored with a policy
that may be set by external tools to store and retrieve arbitrary metadata.
They are not queryable and should be preserved when modifying objects. AIP-
128
Corresponds to the JSON property annotations
2946 2947 2948 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2946 def annotations @annotations end |
#create_time ⇒ String
Output only. The time the policy was created. For singleton policies, this is
the first touch of the policy.
Corresponds to the JSON property createTime
2952 2953 2954 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2952 def create_time @create_time end |
#enable_rules ⇒ Array<Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2alphaEnableRule>
Enable rules define usable services, groups, and categories. There can
currently be at most one EnableRule. This restriction will be lifted in
later releases.
Corresponds to the JSON property enableRules
2959 2960 2961 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2959 def enable_rules @enable_rules end |
#etag ⇒ String
Output only. An opaque tag indicating the current version of the policy, used
for concurrency control.
Corresponds to the JSON property etag
2965 2966 2967 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2965 def etag @etag end |
#name ⇒ String
Output only. The resource name of the policy. Only the default policy is
supported: projects/12345/consumerPolicies/default, folders/12345/
consumerPolicies/default, organizations/12345/consumerPolicies/default.
Corresponds to the JSON property name
2972 2973 2974 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2972 def name @name end |
#update_time ⇒ String
Output only. The time the policy was last updated.
Corresponds to the JSON property updateTime
2977 2978 2979 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2977 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2984 2985 2986 2987 2988 2989 2990 2991 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 2984 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @enable_rules = args[:enable_rules] if args.key?(:enable_rules) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |