Class: Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaAnalysis
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaAnalysis
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
A message to group the analysis information.
Instance Attribute Summary collapse
-
#analysis_result ⇒ Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaAnalysisResult
An analysis result including blockers and warnings.
-
#analysis_type ⇒ String
Output only.
-
#display_name ⇒ String
Output only.
-
#service ⇒ String
The names of the service that has analysis result of warnings or blockers.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleApiServiceusageV2betaAnalysis
constructor
A new instance of GoogleApiServiceusageV2betaAnalysis.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleApiServiceusageV2betaAnalysis
Returns a new instance of GoogleApiServiceusageV2betaAnalysis.
3053 3054 3055 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3053 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_result ⇒ Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaAnalysisResult
An analysis result including blockers and warnings.
Corresponds to the JSON property analysisResult
3034 3035 3036 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3034 def analysis_result @analysis_result end |
#analysis_type ⇒ String
Output only. The type of analysis.
Corresponds to the JSON property analysisType
3039 3040 3041 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3039 def analysis_type @analysis_type end |
#display_name ⇒ String
Output only. The user friendly display name of the analysis type. E.g. service
dependency analysis, service resource usage analysis, etc.
Corresponds to the JSON property displayName
3045 3046 3047 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3045 def display_name @display_name end |
#service ⇒ String
The names of the service that has analysis result of warnings or blockers.
Example: services/storage.googleapis.com.
Corresponds to the JSON property service
3051 3052 3053 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3051 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3058 3059 3060 3061 3062 3063 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3058 def update!(**args) @analysis_result = args[:analysis_result] if args.key?(:analysis_result) @analysis_type = args[:analysis_type] if args.key?(:analysis_type) @display_name = args[:display_name] if args.key?(:display_name) @service = args[:service] if args.key?(:service) end |