Class: Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaAnalysisResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

An analysis result including blockers and warnings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleApiServiceusageV2betaAnalysisResult

Returns a new instance of GoogleApiServiceusageV2betaAnalysisResult.



3081
3082
3083
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3081

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockersArray<Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaImpact>

Blocking information that would prevent the policy changes at runtime. Corresponds to the JSON property blockers



3073
3074
3075
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3073

def blockers
  @blockers
end

#warningsArray<Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaImpact>

Warning information indicating that the policy changes might be unsafe, but will not block the changes at runtime. Corresponds to the JSON property warnings



3079
3080
3081
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3079

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3086
3087
3088
3089
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3086

def update!(**args)
  @blockers = args[:blockers] if args.key?(:blockers)
  @warnings = args[:warnings] if args.key?(:warnings)
end