Class: Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaAnalyzeConsumerPolicyResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

The response of analyzing a consumer policy update.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleApiServiceusageV2betaAnalyzeConsumerPolicyResponse

Returns a new instance of GoogleApiServiceusageV2betaAnalyzeConsumerPolicyResponse.



3117
3118
3119
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3117

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysisArray<Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaAnalysis>

The list of analyses returned from performing the intended policy update analysis. The analysis is grouped by service name and different analysis types. The empty analysis list means that the consumer policy can be updated without any warnings or blockers. Corresponds to the JSON property analysis



3115
3116
3117
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3115

def analysis
  @analysis
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3122
3123
3124
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3122

def update!(**args)
  @analysis = args[:analysis] if args.key?(:analysis)
end