Class: Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaConsumerPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaConsumerPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
Consumer Policy is a set of rules that define what services or service groups can be used for a cloud resource hierarchy.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#enable_rules ⇒ Array<Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaEnableRule>
Enable rules define usable services, groups, and categories.
-
#etag ⇒ String
An opaque tag indicating the current version of the policy, used for concurrency control.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleApiServiceusageV2betaConsumerPolicy
constructor
A new instance of GoogleApiServiceusageV2betaConsumerPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleApiServiceusageV2betaConsumerPolicy
Returns a new instance of GoogleApiServiceusageV2betaConsumerPolicy.
3288 3289 3290 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3288 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the policy was created. For singleton policies, this is
the first touch of the policy.
Corresponds to the JSON property createTime
3261 3262 3263 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3261 def create_time @create_time end |
#enable_rules ⇒ Array<Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaEnableRule>
Enable rules define usable services, groups, and categories. There can
currently be at most one EnableRule. This restriction will be lifted in
later releases.
Corresponds to the JSON property enableRules
3268 3269 3270 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3268 def enable_rules @enable_rules end |
#etag ⇒ String
An opaque tag indicating the current version of the policy, used for
concurrency control.
Corresponds to the JSON property etag
3274 3275 3276 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3274 def etag @etag end |
#name ⇒ String
Output only. The resource name of the policy. Only the default policy is
supported: projects/12345/consumerPolicies/default, folders/12345/
consumerPolicies/default, organizations/12345/consumerPolicies/default.
Corresponds to the JSON property name
3281 3282 3283 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3281 def name @name end |
#update_time ⇒ String
Output only. The time the policy was last updated.
Corresponds to the JSON property updateTime
3286 3287 3288 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3286 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3293 3294 3295 3296 3297 3298 3299 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3293 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @enable_rules = args[:enable_rules] if args.key?(:enable_rules) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |