Class: Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaConsumerPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

Consumer Policy is a set of rules that define what services or service groups can be used for a cloud resource hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleApiServiceusageV2betaConsumerPolicy

Returns a new instance of GoogleApiServiceusageV2betaConsumerPolicy.



3163
3164
3165
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3163

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the policy was created. For singleton policies, this is the first touch of the policy. Corresponds to the JSON property createTime

Returns:

  • (String)


3136
3137
3138
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3136

def create_time
  @create_time
end

#enable_rulesArray<Google::Apis::ServiceusageV1beta1::GoogleApiServiceusageV2betaEnableRule>

Enable rules define usable services, groups, and categories. There can currently be at most one EnableRule. This restriction will be lifted in later releases. Corresponds to the JSON property enableRules



3143
3144
3145
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3143

def enable_rules
  @enable_rules
end

#etagString

An opaque tag indicating the current version of the policy, used for concurrency control. Corresponds to the JSON property etag

Returns:

  • (String)


3149
3150
3151
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3149

def etag
  @etag
end

#nameString

Output only. The resource name of the policy. Only the default policy is supported: projects/12345/consumerPolicies/default, folders/12345/ consumerPolicies/default, organizations/12345/consumerPolicies/default. Corresponds to the JSON property name

Returns:

  • (String)


3156
3157
3158
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3156

def name
  @name
end

#update_timeString

Output only. The time the policy was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3161
3162
3163
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3161

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3168
3169
3170
3171
3172
3173
3174
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3168

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @enable_rules = args[:enable_rules] if args.key?(:enable_rules)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end