Class: Google::Apis::ServiceusageV1beta1::Impact
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::Impact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
A message to group impacts of updating a policy.
Instance Attribute Summary collapse
-
#detail ⇒ String
Output only.
-
#impact_type ⇒ String
Output only.
-
#missing_dependency ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Impact
constructor
A new instance of Impact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Impact
Returns a new instance of Impact.
3733 3734 3735 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3733 def initialize(**args) update!(**args) end |
Instance Attribute Details
#detail ⇒ String
Output only. User friendly impact detail in a free form message.
Corresponds to the JSON property detail
3718 3719 3720 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3718 def detail @detail end |
#impact_type ⇒ String
Output only. The type of impact.
Corresponds to the JSON property impactType
3723 3724 3725 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3723 def impact_type @impact_type end |
#missing_dependency ⇒ String
Output only. This field will be populated only for the
DEPENDENCY_MISSING_DEPENDENCIES impact type. Example: services/compute.
googleapis.com. Impact.detail will be in format : missing service dependency:
missing_dependency.
Corresponds to the JSON property missingDependency
3731 3732 3733 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3731 def missing_dependency @missing_dependency end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3738 3739 3740 3741 3742 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3738 def update!(**args) @detail = args[:detail] if args.key?(:detail) @impact_type = args[:impact_type] if args.key?(:impact_type) @missing_dependency = args[:missing_dependency] if args.key?(:missing_dependency) end |