Class: Google::Apis::ServiceusageV1beta1::Impact
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::Impact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
A message to group impacts of updating a policy.
Instance Attribute Summary collapse
-
#detail ⇒ String
Output only.
-
#impact_type ⇒ String
Output only.
-
#parent ⇒ String
The parent resource that the analysis is based on and the service name that the analysis is for.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Impact
constructor
A new instance of Impact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Impact
Returns a new instance of Impact.
3609 3610 3611 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3609 def initialize(**args) update!(**args) end |
Instance Attribute Details
#detail ⇒ String
Output only. User friendly impact detail in a free form message.
Corresponds to the JSON property detail
3590 3591 3592 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3590 def detail @detail end |
#impact_type ⇒ String
Output only. The type of impact.
Corresponds to the JSON property impactType
3595 3596 3597 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3595 def impact_type @impact_type end |
#parent ⇒ String
The parent resource that the analysis is based on and the service name that
the analysis is for. Example: projects/100/services/compute.googleapis.com,
folders/101/services/compute.googleapis.comandorganizations/102/services/
compute.googleapis.com. Usually, the parent resource here is same as the
parent resource of the analyzed policy. However, for some analysis types, the
parent can be different. For example, for resource existence analysis, if the
parent resource of the analyzed policy is a folder or an organization, the
parent resource here can still be the project that contains the resources.
Corresponds to the JSON propertyparent`
3607 3608 3609 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3607 def parent @parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3614 3615 3616 3617 3618 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3614 def update!(**args) @detail = args[:detail] if args.key?(:detail) @impact_type = args[:impact_type] if args.key?(:impact_type) @parent = args[:parent] if args.key?(:parent) end |