Class: Google::Apis::ServiceusageV1beta1::ImportAdminOverridesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

Request message for ImportAdminOverrides

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImportAdminOverridesRequest

Returns a new instance of ImportAdminOverridesRequest.



3665
3666
3667
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3665

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#forceBoolean Also known as: force?

Whether to force the creation of the quota overrides. Setting the force parameter to 'true' ignores all quota safety checks that would fail the request. QuotaSafetyCheck lists all such validations. If force is set to true, it is recommended to include a case id in "X-Goog-Request-Reason" header when sending the request. Corresponds to the JSON property force

Returns:

  • (Boolean)


3647
3648
3649
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3647

def force
  @force
end

#force_onlyArray<String>

The list of quota safety checks to ignore before the override mutation. Unlike 'force' field that ignores all the quota safety checks, the 'force_only' field ignores only the specified checks; other checks are still enforced. The 'force' and 'force_only' fields cannot both be set. If force_only is specified, it is recommended to include a case id in "X-Goog-Request-Reason" header when sending the request. Corresponds to the JSON property forceOnly

Returns:

  • (Array<String>)


3658
3659
3660
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3658

def force_only
  @force_only
end

#inline_sourceGoogle::Apis::ServiceusageV1beta1::OverrideInlineSource

Import data embedded in the request message Corresponds to the JSON property inlineSource



3663
3664
3665
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3663

def inline_source
  @inline_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3670
3671
3672
3673
3674
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3670

def update!(**args)
  @force = args[:force] if args.key?(:force)
  @force_only = args[:force_only] if args.key?(:force_only)
  @inline_source = args[:inline_source] if args.key?(:inline_source)
end