Class: Google::Apis::ServiceusageV1beta1::ImportAdminOverridesRequest
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::ImportAdminOverridesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
Request message for ImportAdminOverrides
Instance Attribute Summary collapse
-
#force ⇒ Boolean
(also: #force?)
Whether to force the creation of the quota overrides.
-
#force_only ⇒ Array<String>
The list of quota safety checks to ignore before the override mutation.
-
#inline_source ⇒ Google::Apis::ServiceusageV1beta1::OverrideInlineSource
Import data embedded in the request message Corresponds to the JSON property
inlineSource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImportAdminOverridesRequest
constructor
A new instance of ImportAdminOverridesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImportAdminOverridesRequest
Returns a new instance of ImportAdminOverridesRequest.
3668 3669 3670 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3668 def initialize(**args) update!(**args) end |
Instance Attribute Details
#force ⇒ Boolean Also known as: force?
Whether to force the creation of the quota overrides. Setting the force
parameter to 'true' ignores all quota safety checks that would fail the
request. QuotaSafetyCheck lists all such validations. If force is set to true,
it is recommended to include a case id in "X-Goog-Request-Reason" header when
sending the request.
Corresponds to the JSON property force
3650 3651 3652 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3650 def force @force end |
#force_only ⇒ Array<String>
The list of quota safety checks to ignore before the override mutation. Unlike
'force' field that ignores all the quota safety checks, the 'force_only' field
ignores only the specified checks; other checks are still enforced. The 'force'
and 'force_only' fields cannot both be set. If force_only is specified, it is
recommended to include a case id in "X-Goog-Request-Reason" header when
sending the request.
Corresponds to the JSON property forceOnly
3661 3662 3663 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3661 def force_only @force_only end |
#inline_source ⇒ Google::Apis::ServiceusageV1beta1::OverrideInlineSource
Import data embedded in the request message
Corresponds to the JSON property inlineSource
3666 3667 3668 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3666 def inline_source @inline_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3673 3674 3675 3676 3677 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3673 def update!(**args) @force = args[:force] if args.key?(:force) @force_only = args[:force_only] if args.key?(:force_only) @inline_source = args[:inline_source] if args.key?(:inline_source) end |