Class: Google::Apis::ServiceusageV1beta1::ImportConsumerOverridesRequest
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::ImportConsumerOverridesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
Request message for ImportConsumerOverrides
Instance Attribute Summary collapse
-
#force ⇒ Boolean
(also: #force?)
Whether to force the creation of the quota overrides.
-
#force_only ⇒ Array<String>
The list of quota safety checks to ignore before the override mutation.
-
#inline_source ⇒ Google::Apis::ServiceusageV1beta1::OverrideInlineSource
Import data embedded in the request message Corresponds to the JSON property
inlineSource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImportConsumerOverridesRequest
constructor
A new instance of ImportConsumerOverridesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImportConsumerOverridesRequest
Returns a new instance of ImportConsumerOverridesRequest.
3777 3778 3779 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3777 def initialize(**args) update!(**args) end |
Instance Attribute Details
#force ⇒ Boolean Also known as: force?
Whether to force the creation of the quota overrides. Setting the force
parameter to 'true' ignores all quota safety checks that would fail the
request. QuotaSafetyCheck lists all such validations. If force is set to true,
it is recommended to include a case id in "X-Goog-Request-Reason" header when
sending the request.
Corresponds to the JSON property force
3759 3760 3761 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3759 def force @force end |
#force_only ⇒ Array<String>
The list of quota safety checks to ignore before the override mutation. Unlike
'force' field that ignores all the quota safety checks, the 'force_only' field
ignores only the specified checks; other checks are still enforced. The 'force'
and 'force_only' fields cannot both be set. If force_only is specified, it is
recommended to include a case id in "X-Goog-Request-Reason" header when
sending the request.
Corresponds to the JSON property forceOnly
3770 3771 3772 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3770 def force_only @force_only end |
#inline_source ⇒ Google::Apis::ServiceusageV1beta1::OverrideInlineSource
Import data embedded in the request message
Corresponds to the JSON property inlineSource
3775 3776 3777 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3775 def inline_source @inline_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3782 3783 3784 3785 3786 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 3782 def update!(**args) @force = args[:force] if args.key?(:force) @force_only = args[:force_only] if args.key?(:force_only) @inline_source = args[:inline_source] if args.key?(:inline_source) end |