Class: Google::Apis::ServiceusageV1beta1::McpPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::McpPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
MCP Consumer Policy is a set of rules that define MCP related policy for a cloud resource hierarchy.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
An opaque tag indicating the current version of the policy, used for concurrency control.
-
#mcp_enable_rules ⇒ Array<Google::Apis::ServiceusageV1beta1::McpEnableRule>
McpEnableRules contains MCP enablement related rules.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ McpPolicy
constructor
A new instance of McpPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ McpPolicy
Returns a new instance of McpPolicy.
4268 4269 4270 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4268 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the policy was created. For singleton policies (such as
the default policy), this is the first touch of the policy.
Corresponds to the JSON property createTime
4242 4243 4244 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4242 def create_time @create_time end |
#etag ⇒ String
An opaque tag indicating the current version of the policy, used for
concurrency control.
Corresponds to the JSON property etag
4248 4249 4250 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4248 def etag @etag end |
#mcp_enable_rules ⇒ Array<Google::Apis::ServiceusageV1beta1::McpEnableRule>
McpEnableRules contains MCP enablement related rules.
Corresponds to the JSON property mcpEnableRules
4253 4254 4255 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4253 def mcp_enable_rules @mcp_enable_rules end |
#name ⇒ String
Output only. The resource name of the policy. Only the default policy is
supported. We allow the following formats: projects/PROJECT_NUMBER/
mcpPolicies/default, projects/PROJECT_ID/mcpPolicies/default, folders/
FOLDER_ID/mcpPolicies/default, organizations/ORG_ID/mcpPolicies/default.
Corresponds to the JSON property name
4261 4262 4263 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4261 def name @name end |
#update_time ⇒ String
Output only. The time the policy was last updated.
Corresponds to the JSON property updateTime
4266 4267 4268 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4266 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4273 4274 4275 4276 4277 4278 4279 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4273 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @mcp_enable_rules = args[:mcp_enable_rules] if args.key?(:mcp_enable_rules) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |