Class: Google::Apis::ServiceusageV1beta1::MethodPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::MethodPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
Defines policies applying to an RPC method.
Instance Attribute Summary collapse
-
#request_policies ⇒ Array<Google::Apis::ServiceusageV1beta1::FieldPolicy>
Policies that are applicable to the request message.
-
#selector ⇒ String
Selects a method to which these policies should be enforced, for example, " google.pubsub.v1.Subscriber.CreateSubscription".
Instance Method Summary collapse
-
#initialize(**args) ⇒ MethodPolicy
constructor
A new instance of MethodPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MethodPolicy
Returns a new instance of MethodPolicy.
4389 4390 4391 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4389 def initialize(**args) update!(**args) end |
Instance Attribute Details
#request_policies ⇒ Array<Google::Apis::ServiceusageV1beta1::FieldPolicy>
Policies that are applicable to the request message.
Corresponds to the JSON property requestPolicies
4379 4380 4381 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4379 def request_policies @request_policies end |
#selector ⇒ String
Selects a method to which these policies should be enforced, for example, "
google.pubsub.v1.Subscriber.CreateSubscription". Refer to selector for syntax
details. NOTE: This field must not be set in the proto annotation. It will be
automatically filled by the service config compiler .
Corresponds to the JSON property selector
4387 4388 4389 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4387 def selector @selector end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4394 4395 4396 4397 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4394 def update!(**args) @request_policies = args[:request_policies] if args.key?(:request_policies) @selector = args[:selector] if args.key?(:selector) end |