Class: Google::Apis::ServiceusageV1beta1::MethodProp
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::MethodProp
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
Method represents a method of an API interface. New usages of this message as an alternative to MethodDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
-
#name ⇒ String
The simple name of this method.
-
#options ⇒ Array<Google::Apis::ServiceusageV1beta1::Option>
Any metadata attached to the method.
-
#request_streaming ⇒ Boolean
(also: #request_streaming?)
If true, the request is streamed.
-
#request_type_url ⇒ String
A URL of the input message type.
-
#response_streaming ⇒ Boolean
(also: #response_streaming?)
If true, the response is streamed.
-
#response_type_url ⇒ String
The URL of the output message type.
-
#syntax ⇒ String
The source syntax of this method.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MethodProp
constructor
A new instance of MethodProp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MethodProp
Returns a new instance of MethodProp.
4388 4389 4390 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4388 def initialize(**args) update!(**args) end |
Instance Attribute Details
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS. This
field should be ignored, instead the edition should be inherited from Api.
This is similar to Field and EnumValue.
Corresponds to the JSON property edition
4348 4349 4350 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4348 def edition @edition end |
#name ⇒ String
The simple name of this method.
Corresponds to the JSON property name
4353 4354 4355 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4353 def name @name end |
#options ⇒ Array<Google::Apis::ServiceusageV1beta1::Option>
Any metadata attached to the method.
Corresponds to the JSON property options
4358 4359 4360 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4358 def @options end |
#request_streaming ⇒ Boolean Also known as: request_streaming?
If true, the request is streamed.
Corresponds to the JSON property requestStreaming
4363 4364 4365 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4363 def request_streaming @request_streaming end |
#request_type_url ⇒ String
A URL of the input message type.
Corresponds to the JSON property requestTypeUrl
4369 4370 4371 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4369 def request_type_url @request_type_url end |
#response_streaming ⇒ Boolean Also known as: response_streaming?
If true, the response is streamed.
Corresponds to the JSON property responseStreaming
4374 4375 4376 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4374 def response_streaming @response_streaming end |
#response_type_url ⇒ String
The URL of the output message type.
Corresponds to the JSON property responseTypeUrl
4380 4381 4382 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4380 def response_type_url @response_type_url end |
#syntax ⇒ String
The source syntax of this method. This field should be ignored, instead the
syntax should be inherited from Api. This is similar to Field and EnumValue.
Corresponds to the JSON property syntax
4386 4387 4388 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4386 def syntax @syntax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4393 4394 4395 4396 4397 4398 4399 4400 4401 4402 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4393 def update!(**args) @edition = args[:edition] if args.key?(:edition) @name = args[:name] if args.key?(:name) @options = args[:options] if args.key?(:options) @request_streaming = args[:request_streaming] if args.key?(:request_streaming) @request_type_url = args[:request_type_url] if args.key?(:request_type_url) @response_streaming = args[:response_streaming] if args.key?(:response_streaming) @response_type_url = args[:response_type_url] if args.key?(:response_type_url) @syntax = args[:syntax] if args.key?(:syntax) end |