Class: Google::Apis::ServiceusageV1beta1::MethodProp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

Method represents a method of an API interface. New usages of this message as an alternative to MethodDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MethodProp

Returns a new instance of MethodProp.



4264
4265
4266
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4264

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editionString

The source edition string, only valid when syntax is SYNTAX_EDITIONS. This field should be ignored, instead the edition should be inherited from Api. This is similar to Field and EnumValue. Corresponds to the JSON property edition

Returns:

  • (String)


4224
4225
4226
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4224

def edition
  @edition
end

#nameString

The simple name of this method. Corresponds to the JSON property name

Returns:

  • (String)


4229
4230
4231
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4229

def name
  @name
end

#optionsArray<Google::Apis::ServiceusageV1beta1::Option>

Any metadata attached to the method. Corresponds to the JSON property options



4234
4235
4236
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4234

def options
  @options
end

#request_streamingBoolean Also known as: request_streaming?

If true, the request is streamed. Corresponds to the JSON property requestStreaming

Returns:

  • (Boolean)


4239
4240
4241
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4239

def request_streaming
  @request_streaming
end

#request_type_urlString

A URL of the input message type. Corresponds to the JSON property requestTypeUrl

Returns:

  • (String)


4245
4246
4247
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4245

def request_type_url
  @request_type_url
end

#response_streamingBoolean Also known as: response_streaming?

If true, the response is streamed. Corresponds to the JSON property responseStreaming

Returns:

  • (Boolean)


4250
4251
4252
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4250

def response_streaming
  @response_streaming
end

#response_type_urlString

The URL of the output message type. Corresponds to the JSON property responseTypeUrl

Returns:

  • (String)


4256
4257
4258
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4256

def response_type_url
  @response_type_url
end

#syntaxString

The source syntax of this method. This field should be ignored, instead the syntax should be inherited from Api. This is similar to Field and EnumValue. Corresponds to the JSON property syntax

Returns:

  • (String)


4262
4263
4264
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4262

def syntax
  @syntax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4269

def update!(**args)
  @edition = args[:edition] if args.key?(:edition)
  @name = args[:name] if args.key?(:name)
  @options = args[:options] if args.key?(:options)
  @request_streaming = args[:request_streaming] if args.key?(:request_streaming)
  @request_type_url = args[:request_type_url] if args.key?(:request_type_url)
  @response_streaming = args[:response_streaming] if args.key?(:response_streaming)
  @response_type_url = args[:response_type_url] if args.key?(:response_type_url)
  @syntax = args[:syntax] if args.key?(:syntax)
end