Class: Google::Apis::ServiceusageV1beta1::MethodProp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

Method represents a method of an API interface. New usages of this message as an alternative to MethodDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MethodProp

Returns a new instance of MethodProp.



4355
4356
4357
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4355

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editionString

The source edition string, only valid when syntax is SYNTAX_EDITIONS. This field should be ignored, instead the edition should be inherited from Api. This is similar to Field and EnumValue. Corresponds to the JSON property edition

Returns:

  • (String)


4315
4316
4317
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4315

def edition
  @edition
end

#nameString

The simple name of this method. Corresponds to the JSON property name

Returns:

  • (String)


4320
4321
4322
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4320

def name
  @name
end

#optionsArray<Google::Apis::ServiceusageV1beta1::Option>

Any metadata attached to the method. Corresponds to the JSON property options



4325
4326
4327
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4325

def options
  @options
end

#request_streamingBoolean Also known as: request_streaming?

If true, the request is streamed. Corresponds to the JSON property requestStreaming

Returns:

  • (Boolean)


4330
4331
4332
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4330

def request_streaming
  @request_streaming
end

#request_type_urlString

A URL of the input message type. Corresponds to the JSON property requestTypeUrl

Returns:

  • (String)


4336
4337
4338
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4336

def request_type_url
  @request_type_url
end

#response_streamingBoolean Also known as: response_streaming?

If true, the response is streamed. Corresponds to the JSON property responseStreaming

Returns:

  • (Boolean)


4341
4342
4343
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4341

def response_streaming
  @response_streaming
end

#response_type_urlString

The URL of the output message type. Corresponds to the JSON property responseTypeUrl

Returns:

  • (String)


4347
4348
4349
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4347

def response_type_url
  @response_type_url
end

#syntaxString

The source syntax of this method. This field should be ignored, instead the syntax should be inherited from Api. This is similar to Field and EnumValue. Corresponds to the JSON property syntax

Returns:

  • (String)


4353
4354
4355
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4353

def syntax
  @syntax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4360
4361
4362
4363
4364
4365
4366
4367
4368
4369
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4360

def update!(**args)
  @edition = args[:edition] if args.key?(:edition)
  @name = args[:name] if args.key?(:name)
  @options = args[:options] if args.key?(:options)
  @request_streaming = args[:request_streaming] if args.key?(:request_streaming)
  @request_type_url = args[:request_type_url] if args.key?(:request_type_url)
  @response_streaming = args[:response_streaming] if args.key?(:response_streaming)
  @response_type_url = args[:response_type_url] if args.key?(:response_type_url)
  @syntax = args[:syntax] if args.key?(:syntax)
end