Class: Google::Apis::ServiceusageV1beta1::MetricDescriptorMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::MetricDescriptorMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
Additional annotations that can be used to guide the usage of a metric.
Instance Attribute Summary collapse
-
#ingest_delay ⇒ String
The delay of data points caused by ingestion.
-
#launch_stage ⇒ String
Deprecated.
-
#sample_period ⇒ String
The sampling period of metric data points.
-
#time_series_resource_hierarchy_level ⇒ Array<String>
The scope of the timeseries data of the metric.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetricDescriptorMetadata
constructor
A new instance of MetricDescriptorMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetricDescriptorMetadata
Returns a new instance of MetricDescriptorMetadata.
4529 4530 4531 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4529 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ingest_delay ⇒ String
The delay of data points caused by ingestion. Data points older than this age
are guaranteed to be ingested and available to be read, excluding data loss
due to errors.
Corresponds to the JSON property ingestDelay
4509 4510 4511 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4509 def ingest_delay @ingest_delay end |
#launch_stage ⇒ String
Deprecated. Must use the MetricDescriptor.launch_stage instead.
Corresponds to the JSON property launchStage
4514 4515 4516 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4514 def launch_stage @launch_stage end |
#sample_period ⇒ String
The sampling period of metric data points. For metrics which are written
periodically, consecutive data points are stored at this time interval,
excluding data loss due to errors. Metrics with a higher granularity have a
smaller sampling period.
Corresponds to the JSON property samplePeriod
4522 4523 4524 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4522 def sample_period @sample_period end |
#time_series_resource_hierarchy_level ⇒ Array<String>
The scope of the timeseries data of the metric.
Corresponds to the JSON property timeSeriesResourceHierarchyLevel
4527 4528 4529 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4527 def time_series_resource_hierarchy_level @time_series_resource_hierarchy_level end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4534 4535 4536 4537 4538 4539 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4534 def update!(**args) @ingest_delay = args[:ingest_delay] if args.key?(:ingest_delay) @launch_stage = args[:launch_stage] if args.key?(:launch_stage) @sample_period = args[:sample_period] if args.key?(:sample_period) @time_series_resource_hierarchy_level = args[:time_series_resource_hierarchy_level] if args.key?(:time_series_resource_hierarchy_level) end |