Class: Google::Apis::ServiceusageV1beta1::MetricRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

Bind API methods to metrics. Binding a method to a metric causes that metric's configured quota behaviors to apply to the method call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MetricRule

Returns a new instance of MetricRule.



4703
4704
4705
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4703

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agentic_metric_costsHash<String,Fixnum>

Optional. Metrics to update when the selected methods are called, and the associated cost applied to each metric, iff the source of the call is an agent. The key of the map is the metric name, and the values are the amount increased for the metric against which the quota limits are defined. The value must not be negative. Corresponds to the JSON property agenticMetricCosts

Returns:

  • (Hash<String,Fixnum>)


4678
4679
4680
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4678

def agentic_metric_costs
  @agentic_metric_costs
end

#metric_costsHash<String,Fixnum>

Metrics to update when the selected methods are called, and the associated cost applied to each metric. The key of the map is the metric name, and the values are the amount increased for the metric against which the quota limits are defined. The value must not be negative. Corresponds to the JSON property metricCosts

Returns:

  • (Hash<String,Fixnum>)


4686
4687
4688
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4686

def metric_costs
  @metric_costs
end

#nonagentic_metric_costsHash<String,Fixnum>

Optional. Metrics to update when the selected methods are called, and the associated cost applied to each metric, iff the source of the call is not an agent. The key of the map is the metric name, and the values are the amount increased for the metric against which the quota limits are defined. The value must not be negative. Corresponds to the JSON property nonagenticMetricCosts

Returns:

  • (Hash<String,Fixnum>)


4695
4696
4697
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4695

def nonagentic_metric_costs
  @nonagentic_metric_costs
end

#selectorString

Selects the methods to which this rule applies. Refer to selector for syntax details. Corresponds to the JSON property selector

Returns:

  • (String)


4701
4702
4703
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4701

def selector
  @selector
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4708
4709
4710
4711
4712
4713
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4708

def update!(**args)
  @agentic_metric_costs = args[:agentic_metric_costs] if args.key?(:agentic_metric_costs)
  @metric_costs = args[:metric_costs] if args.key?(:metric_costs)
  @nonagentic_metric_costs = args[:nonagentic_metric_costs] if args.key?(:nonagentic_metric_costs)
  @selector = args[:selector] if args.key?(:selector)
end