Class: Google::Apis::ServiceusageV1beta1::MetricRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

Bind API methods to metrics. Binding a method to a metric causes that metric's configured quota behaviors to apply to the method call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MetricRule

Returns a new instance of MetricRule.



4561
4562
4563
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4561

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metric_costsHash<String,Fixnum>

Metrics to update when the selected methods are called, and the associated cost applied to each metric. The key of the map is the metric name, and the values are the amount increased for the metric against which the quota limits are defined. The value must not be negative. Corresponds to the JSON property metricCosts

Returns:

  • (Hash<String,Fixnum>)


4553
4554
4555
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4553

def metric_costs
  @metric_costs
end

#selectorString

Selects the methods to which this rule applies. Refer to selector for syntax details. Corresponds to the JSON property selector

Returns:

  • (String)


4559
4560
4561
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4559

def selector
  @selector
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4566
4567
4568
4569
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 4566

def update!(**args)
  @metric_costs = args[:metric_costs] if args.key?(:metric_costs)
  @selector = args[:selector] if args.key?(:selector)
end