Class: Google::Apis::ServiceusageV1beta1::Publishing
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::Publishing
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
This message configures the settings for publishing Google Cloud Client libraries generated from the service config.
Instance Attribute Summary collapse
-
#api_short_name ⇒ String
Used as a tracking tag when collecting data about the APIs developer relations artifacts like docs, packages delivered to package managers, etc.
-
#codeowner_github_teams ⇒ Array<String>
GitHub teams to be added to CODEOWNERS in the directory in GitHub containing source code for the client libraries for this API.
-
#doc_tag_prefix ⇒ String
A prefix used in sample code when demarking regions to be included in documentation.
-
#documentation_uri ⇒ String
Link to product home page.
-
#github_label ⇒ String
GitHub label to apply to issues and pull requests opened for this API.
-
#library_settings ⇒ Array<Google::Apis::ServiceusageV1beta1::ClientLibrarySettings>
Client library settings.
-
#method_settings ⇒ Array<Google::Apis::ServiceusageV1beta1::MethodSettings>
A list of API method settings, e.g.
-
#new_issue_uri ⇒ String
Link to a public URI where users can report issues.
-
#organization ⇒ String
For whom the client library is being published.
-
#proto_reference_documentation_uri ⇒ String
Optional link to proto reference documentation.
-
#rest_reference_documentation_uri ⇒ String
Optional link to REST reference documentation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Publishing
constructor
A new instance of Publishing.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Publishing
Returns a new instance of Publishing.
5305 5306 5307 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5305 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_short_name ⇒ String
Used as a tracking tag when collecting data about the APIs developer relations
artifacts like docs, packages delivered to package managers, etc. Example: "
speech".
Corresponds to the JSON property apiShortName
5244 5245 5246 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5244 def api_short_name @api_short_name end |
#codeowner_github_teams ⇒ Array<String>
GitHub teams to be added to CODEOWNERS in the directory in GitHub containing
source code for the client libraries for this API.
Corresponds to the JSON property codeownerGithubTeams
5250 5251 5252 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5250 def codeowner_github_teams @codeowner_github_teams end |
#doc_tag_prefix ⇒ String
A prefix used in sample code when demarking regions to be included in
documentation.
Corresponds to the JSON property docTagPrefix
5256 5257 5258 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5256 def doc_tag_prefix @doc_tag_prefix end |
#documentation_uri ⇒ String
Link to product home page. Example: https://cloud.google.com/asset-inventory/
docs/overview
Corresponds to the JSON property documentationUri
5262 5263 5264 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5262 def documentation_uri @documentation_uri end |
#github_label ⇒ String
GitHub label to apply to issues and pull requests opened for this API.
Corresponds to the JSON property githubLabel
5267 5268 5269 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5267 def github_label @github_label end |
#library_settings ⇒ Array<Google::Apis::ServiceusageV1beta1::ClientLibrarySettings>
Client library settings. If the same version string appears multiple times in
this list, then the last one wins. Settings from earlier settings with the
same version string are discarded.
Corresponds to the JSON property librarySettings
5274 5275 5276 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5274 def library_settings @library_settings end |
#method_settings ⇒ Array<Google::Apis::ServiceusageV1beta1::MethodSettings>
A list of API method settings, e.g. the behavior for methods that use the long-
running operation pattern.
Corresponds to the JSON property methodSettings
5280 5281 5282 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5280 def method_settings @method_settings end |
#new_issue_uri ⇒ String
Link to a public URI where users can report issues. Example: https://
issuetracker.google.com/issues/new?component=190865&template=1161103
Corresponds to the JSON property newIssueUri
5286 5287 5288 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5286 def new_issue_uri @new_issue_uri end |
#organization ⇒ String
For whom the client library is being published.
Corresponds to the JSON property organization
5291 5292 5293 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5291 def organization @organization end |
#proto_reference_documentation_uri ⇒ String
Optional link to proto reference documentation. Example: https://cloud.google.
com/pubsub/lite/docs/reference/rpc
Corresponds to the JSON property protoReferenceDocumentationUri
5297 5298 5299 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5297 def proto_reference_documentation_uri @proto_reference_documentation_uri end |
#rest_reference_documentation_uri ⇒ String
Optional link to REST reference documentation. Example: https://cloud.google.
com/pubsub/lite/docs/reference/rest
Corresponds to the JSON property restReferenceDocumentationUri
5303 5304 5305 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5303 def rest_reference_documentation_uri @rest_reference_documentation_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5310 5311 5312 5313 5314 5315 5316 5317 5318 5319 5320 5321 5322 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5310 def update!(**args) @api_short_name = args[:api_short_name] if args.key?(:api_short_name) @codeowner_github_teams = args[:codeowner_github_teams] if args.key?(:codeowner_github_teams) @doc_tag_prefix = args[:doc_tag_prefix] if args.key?(:doc_tag_prefix) @documentation_uri = args[:documentation_uri] if args.key?(:documentation_uri) @github_label = args[:github_label] if args.key?(:github_label) @library_settings = args[:library_settings] if args.key?(:library_settings) @method_settings = args[:method_settings] if args.key?(:method_settings) @new_issue_uri = args[:new_issue_uri] if args.key?(:new_issue_uri) @organization = args[:organization] if args.key?(:organization) @proto_reference_documentation_uri = args[:proto_reference_documentation_uri] if args.key?(:proto_reference_documentation_uri) @rest_reference_documentation_uri = args[:rest_reference_documentation_uri] if args.key?(:rest_reference_documentation_uri) end |