Class: Google::Apis::ServiceusageV1beta1::PythonSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

Settings for Python client libraries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PythonSettings

Returns a new instance of PythonSettings.



5360
5361
5362
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5360

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commonGoogle::Apis::ServiceusageV1beta1::CommonLanguageSettings

Required information for every language. Corresponds to the JSON property common



5352
5353
5354
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5352

def common
  @common
end

#experimental_featuresGoogle::Apis::ServiceusageV1beta1::ExperimentalFeatures

Experimental features to be included during client library generation. These fields will be deprecated once the feature graduates and is enabled by default. Corresponds to the JSON property experimentalFeatures



5358
5359
5360
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5358

def experimental_features
  @experimental_features
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5365
5366
5367
5368
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5365

def update!(**args)
  @common = args[:common] if args.key?(:common)
  @experimental_features = args[:experimental_features] if args.key?(:experimental_features)
end