Class: Google::Apis::ServiceusageV1beta1::PythonSettings
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::PythonSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
Settings for Python client libraries.
Instance Attribute Summary collapse
-
#common ⇒ Google::Apis::ServiceusageV1beta1::CommonLanguageSettings
Required information for every language.
-
#experimental_features ⇒ Google::Apis::ServiceusageV1beta1::ExperimentalFeatures
Experimental features to be included during client library generation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PythonSettings
constructor
A new instance of PythonSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PythonSettings
Returns a new instance of PythonSettings.
5340 5341 5342 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5340 def initialize(**args) update!(**args) end |
Instance Attribute Details
#common ⇒ Google::Apis::ServiceusageV1beta1::CommonLanguageSettings
Required information for every language.
Corresponds to the JSON property common
5332 5333 5334 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5332 def common @common end |
#experimental_features ⇒ Google::Apis::ServiceusageV1beta1::ExperimentalFeatures
Experimental features to be included during client library generation. These
fields will be deprecated once the feature graduates and is enabled by default.
Corresponds to the JSON property experimentalFeatures
5338 5339 5340 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5338 def experimental_features @experimental_features end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5345 5346 5347 5348 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5345 def update!(**args) @common = args[:common] if args.key?(:common) @experimental_features = args[:experimental_features] if args.key?(:experimental_features) end |