Class: Google::Apis::ServiceusageV1beta1::QuotaLimit
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::QuotaLimit
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
QuotaLimit defines a specific limit that applies over a specified duration
for a limit type. There can be at most one limit for a duration and limit type
combination defined within a QuotaGroup.
Instance Attribute Summary collapse
-
#default_limit ⇒ Fixnum
Default number of tokens that can be consumed during the specified duration.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
User-visible display name for this limit.
-
#duration ⇒ String
Duration of this limit in textual notation.
-
#free_tier ⇒ Fixnum
Free tier value displayed in the Developers Console for this limit.
-
#max_limit ⇒ Fixnum
Maximum number of tokens that can be consumed during the specified duration.
-
#metric ⇒ String
The name of the metric this quota limit applies to.
-
#name ⇒ String
Name of the quota limit.
-
#unit ⇒ String
Specify the unit of the quota limit.
-
#values ⇒ Hash<String,Fixnum>
Tiered limit values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QuotaLimit
constructor
A new instance of QuotaLimit.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QuotaLimit
Returns a new instance of QuotaLimit.
5428 5429 5430 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5428 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_limit ⇒ Fixnum
Default number of tokens that can be consumed during the specified duration.
This is the number of tokens assigned when a client application developer
activates the service for his/her project. Specifying a value of 0 will block
all requests. This can be used if you are provisioning quota to selected
consumers and blocking others. Similarly, a value of -1 will indicate an
unlimited quota. No other negative values are allowed. Used by group-based
quotas only.
Corresponds to the JSON property defaultLimit
5355 5356 5357 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5355 def default_limit @default_limit end |
#description ⇒ String
Optional. User-visible, extended description for this quota limit. Should be
used only when more context is needed to understand this limit than provided
by the limit's display name (see: display_name).
Corresponds to the JSON property description
5362 5363 5364 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5362 def description @description end |
#display_name ⇒ String
User-visible display name for this limit. Optional. If not set, the UI will
provide a default display name based on the quota configuration. This field
can be used to override the default display name generated from the
configuration.
Corresponds to the JSON property displayName
5370 5371 5372 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5370 def display_name @display_name end |
#duration ⇒ String
Duration of this limit in textual notation. Must be "100s" or "1d". Used by
group-based quotas only.
Corresponds to the JSON property duration
5376 5377 5378 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5376 def duration @duration end |
#free_tier ⇒ Fixnum
Free tier value displayed in the Developers Console for this limit. The free
tier is the number of tokens that will be subtracted from the billed amount
when billing is enabled. This field can only be set on a limit with duration "
1d", in a billable group; it is invalid on any other limit. If this field is
not set, it defaults to 0, indicating that there is no free tier for this
service. Used by group-based quotas only.
Corresponds to the JSON property freeTier
5386 5387 5388 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5386 def free_tier @free_tier end |
#max_limit ⇒ Fixnum
Maximum number of tokens that can be consumed during the specified duration.
Client application developers can override the default limit up to this
maximum. If specified, this value cannot be set to a value less than the
default limit. If not specified, it is set to the default limit. To allow
clients to apply overrides with no upper bound, set this to -1, indicating
unlimited maximum quota. Used by group-based quotas only.
Corresponds to the JSON property maxLimit
5396 5397 5398 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5396 def max_limit @max_limit end |
#metric ⇒ String
The name of the metric this quota limit applies to. The quota limits with the
same metric will be checked together during runtime. The metric must be
defined within the service config.
Corresponds to the JSON property metric
5403 5404 5405 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5403 def metric @metric end |
#name ⇒ String
Name of the quota limit. The name must be provided, and it must be unique
within the service. The name can only include alphanumeric characters as well
as '-'. The maximum length of the limit name is 64 characters.
Corresponds to the JSON property name
5410 5411 5412 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5410 def name @name end |
#unit ⇒ String
Specify the unit of the quota limit. It uses the same syntax as
MetricDescriptor.unit. The supported unit kinds are determined by the quota
backend system. Here are some examples: * "1/min/project" for quota per
minute per project. Note: the order of unit components is insignificant. The "
1" at the beginning is required to follow the metric unit syntax.
Corresponds to the JSON property unit
5419 5420 5421 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5419 def unit @unit end |
#values ⇒ Hash<String,Fixnum>
Tiered limit values. You must specify this as a key:value pair, with an
integer value that is the maximum number of requests allowed for the specified
unit. Currently only STANDARD is supported.
Corresponds to the JSON property values
5426 5427 5428 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5426 def values @values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 5433 def update!(**args) @default_limit = args[:default_limit] if args.key?(:default_limit) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @duration = args[:duration] if args.key?(:duration) @free_tier = args[:free_tier] if args.key?(:free_tier) @max_limit = args[:max_limit] if args.key?(:max_limit) @metric = args[:metric] if args.key?(:metric) @name = args[:name] if args.key?(:name) @unit = args[:unit] if args.key?(:unit) @values = args[:values] if args.key?(:values) end |