Class: Google::Apis::ServiceusageV1beta1::Type

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb

Overview

A protocol buffer message type. New usages of this message as an alternative to DescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Type

Returns a new instance of Type.



6224
6225
6226
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6224

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editionString

The source edition string, only valid when syntax is SYNTAX_EDITIONS. Corresponds to the JSON property edition

Returns:

  • (String)


6191
6192
6193
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6191

def edition
  @edition
end

#fieldsArray<Google::Apis::ServiceusageV1beta1::Field>

The list of fields. Corresponds to the JSON property fields



6196
6197
6198
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6196

def fields
  @fields
end

#nameString

The fully qualified message name. Corresponds to the JSON property name

Returns:

  • (String)


6201
6202
6203
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6201

def name
  @name
end

#oneofsArray<String>

The list of types appearing in oneof definitions in this type. Corresponds to the JSON property oneofs

Returns:

  • (Array<String>)


6206
6207
6208
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6206

def oneofs
  @oneofs
end

#optionsArray<Google::Apis::ServiceusageV1beta1::Option>

The protocol buffer options. Corresponds to the JSON property options



6211
6212
6213
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6211

def options
  @options
end

#source_contextGoogle::Apis::ServiceusageV1beta1::SourceContext

SourceContext represents information about the source of a protobuf element, like the file in which it is defined. Corresponds to the JSON property sourceContext



6217
6218
6219
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6217

def source_context
  @source_context
end

#syntaxString

The source syntax. Corresponds to the JSON property syntax

Returns:

  • (String)


6222
6223
6224
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6222

def syntax
  @syntax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6229
6230
6231
6232
6233
6234
6235
6236
6237
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6229

def update!(**args)
  @edition = args[:edition] if args.key?(:edition)
  @fields = args[:fields] if args.key?(:fields)
  @name = args[:name] if args.key?(:name)
  @oneofs = args[:oneofs] if args.key?(:oneofs)
  @options = args[:options] if args.key?(:options)
  @source_context = args[:source_context] if args.key?(:source_context)
  @syntax = args[:syntax] if args.key?(:syntax)
end