Class: Google::Apis::ServiceusageV1beta1::Type
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::Type
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
A protocol buffer message type. New usages of this message as an alternative to DescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
-
#fields ⇒ Array<Google::Apis::ServiceusageV1beta1::Field>
The list of fields.
-
#name ⇒ String
The fully qualified message name.
-
#oneofs ⇒ Array<String>
The list of types appearing in
oneofdefinitions in this type. -
#options ⇒ Array<Google::Apis::ServiceusageV1beta1::Option>
The protocol buffer options.
-
#source_context ⇒ Google::Apis::ServiceusageV1beta1::SourceContext
SourceContextrepresents information about the source of a protobuf element, like the file in which it is defined. -
#syntax ⇒ String
The source syntax.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Type
constructor
A new instance of Type.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Type
Returns a new instance of Type.
6217 6218 6219 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6217 def initialize(**args) update!(**args) end |
Instance Attribute Details
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
Corresponds to the JSON property edition
6184 6185 6186 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6184 def edition @edition end |
#fields ⇒ Array<Google::Apis::ServiceusageV1beta1::Field>
The list of fields.
Corresponds to the JSON property fields
6189 6190 6191 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6189 def fields @fields end |
#name ⇒ String
The fully qualified message name.
Corresponds to the JSON property name
6194 6195 6196 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6194 def name @name end |
#oneofs ⇒ Array<String>
The list of types appearing in oneof definitions in this type.
Corresponds to the JSON property oneofs
6199 6200 6201 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6199 def oneofs @oneofs end |
#options ⇒ Array<Google::Apis::ServiceusageV1beta1::Option>
The protocol buffer options.
Corresponds to the JSON property options
6204 6205 6206 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6204 def @options end |
#source_context ⇒ Google::Apis::ServiceusageV1beta1::SourceContext
SourceContext represents information about the source of a protobuf element,
like the file in which it is defined.
Corresponds to the JSON property sourceContext
6210 6211 6212 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6210 def source_context @source_context end |
#syntax ⇒ String
The source syntax.
Corresponds to the JSON property syntax
6215 6216 6217 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6215 def syntax @syntax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6222 6223 6224 6225 6226 6227 6228 6229 6230 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6222 def update!(**args) @edition = args[:edition] if args.key?(:edition) @fields = args[:fields] if args.key?(:fields) @name = args[:name] if args.key?(:name) @oneofs = args[:oneofs] if args.key?(:oneofs) @options = args[:options] if args.key?(:options) @source_context = args[:source_context] if args.key?(:source_context) @syntax = args[:syntax] if args.key?(:syntax) end |