Class: Google::Apis::ServiceusageV1beta1::Type
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::Type
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
A protocol buffer message type. New usages of this message as an alternative to DescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
-
#fields ⇒ Array<Google::Apis::ServiceusageV1beta1::Field>
The list of fields.
-
#name ⇒ String
The fully qualified message name.
-
#oneofs ⇒ Array<String>
The list of types appearing in
oneofdefinitions in this type. -
#options ⇒ Array<Google::Apis::ServiceusageV1beta1::Option>
The protocol buffer options.
-
#source_context ⇒ Google::Apis::ServiceusageV1beta1::SourceContext
SourceContextrepresents information about the source of a protobuf element, like the file in which it is defined. -
#syntax ⇒ String
The source syntax.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Type
constructor
A new instance of Type.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Type
Returns a new instance of Type.
6189 6190 6191 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6189 def initialize(**args) update!(**args) end |
Instance Attribute Details
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
Corresponds to the JSON property edition
6156 6157 6158 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6156 def edition @edition end |
#fields ⇒ Array<Google::Apis::ServiceusageV1beta1::Field>
The list of fields.
Corresponds to the JSON property fields
6161 6162 6163 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6161 def fields @fields end |
#name ⇒ String
The fully qualified message name.
Corresponds to the JSON property name
6166 6167 6168 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6166 def name @name end |
#oneofs ⇒ Array<String>
The list of types appearing in oneof definitions in this type.
Corresponds to the JSON property oneofs
6171 6172 6173 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6171 def oneofs @oneofs end |
#options ⇒ Array<Google::Apis::ServiceusageV1beta1::Option>
The protocol buffer options.
Corresponds to the JSON property options
6176 6177 6178 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6176 def @options end |
#source_context ⇒ Google::Apis::ServiceusageV1beta1::SourceContext
SourceContext represents information about the source of a protobuf element,
like the file in which it is defined.
Corresponds to the JSON property sourceContext
6182 6183 6184 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6182 def source_context @source_context end |
#syntax ⇒ String
The source syntax.
Corresponds to the JSON property syntax
6187 6188 6189 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6187 def syntax @syntax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6194 6195 6196 6197 6198 6199 6200 6201 6202 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6194 def update!(**args) @edition = args[:edition] if args.key?(:edition) @fields = args[:fields] if args.key?(:fields) @name = args[:name] if args.key?(:name) @oneofs = args[:oneofs] if args.key?(:oneofs) @options = args[:options] if args.key?(:options) @source_context = args[:source_context] if args.key?(:source_context) @syntax = args[:syntax] if args.key?(:syntax) end |