Class: Google::Apis::ServiceusageV1beta1::Type
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1beta1::Type
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1beta1/classes.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb,
lib/google/apis/serviceusage_v1beta1/representations.rb
Overview
A protocol buffer message type. New usages of this message as an alternative to DescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
-
#fields ⇒ Array<Google::Apis::ServiceusageV1beta1::Field>
The list of fields.
-
#name ⇒ String
The fully qualified message name.
-
#oneofs ⇒ Array<String>
The list of types appearing in
oneofdefinitions in this type. -
#options ⇒ Array<Google::Apis::ServiceusageV1beta1::Option>
The protocol buffer options.
-
#source_context ⇒ Google::Apis::ServiceusageV1beta1::SourceContext
SourceContextrepresents information about the source of a protobuf element, like the file in which it is defined. -
#syntax ⇒ String
The source syntax.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Type
constructor
A new instance of Type.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Type
Returns a new instance of Type.
6155 6156 6157 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6155 def initialize(**args) update!(**args) end |
Instance Attribute Details
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
Corresponds to the JSON property edition
6122 6123 6124 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6122 def edition @edition end |
#fields ⇒ Array<Google::Apis::ServiceusageV1beta1::Field>
The list of fields.
Corresponds to the JSON property fields
6127 6128 6129 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6127 def fields @fields end |
#name ⇒ String
The fully qualified message name.
Corresponds to the JSON property name
6132 6133 6134 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6132 def name @name end |
#oneofs ⇒ Array<String>
The list of types appearing in oneof definitions in this type.
Corresponds to the JSON property oneofs
6137 6138 6139 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6137 def oneofs @oneofs end |
#options ⇒ Array<Google::Apis::ServiceusageV1beta1::Option>
The protocol buffer options.
Corresponds to the JSON property options
6142 6143 6144 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6142 def @options end |
#source_context ⇒ Google::Apis::ServiceusageV1beta1::SourceContext
SourceContext represents information about the source of a protobuf element,
like the file in which it is defined.
Corresponds to the JSON property sourceContext
6148 6149 6150 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6148 def source_context @source_context end |
#syntax ⇒ String
The source syntax.
Corresponds to the JSON property syntax
6153 6154 6155 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6153 def syntax @syntax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6160 6161 6162 6163 6164 6165 6166 6167 6168 |
# File 'lib/google/apis/serviceusage_v1beta1/classes.rb', line 6160 def update!(**args) @edition = args[:edition] if args.key?(:edition) @fields = args[:fields] if args.key?(:fields) @name = args[:name] if args.key?(:name) @oneofs = args[:oneofs] if args.key?(:oneofs) @options = args[:options] if args.key?(:options) @source_context = args[:source_context] if args.key?(:source_context) @syntax = args[:syntax] if args.key?(:syntax) end |